####If you want to clear the environment first
rm(list = ls())

library(dplyr)
library(ggplot2)
library(tidyr)
library(margins)
#install.packages("stargazer") # For pretty latex tables
library(stargazer)
#install.packages("mfx")
library(mfx)
#install.packages("DescTools") # For McFadden's R squared
library(DescTools)
library(betareg)
#install.packages("AER") # For coeftest() to get p values for polr
library(AER)
#install.packages("expss") # For labels
library(expss)
library(xtable)
library(lmtest) # Robust SE on linear models
library(sandwich) # Robust standard errors
#install.packages("fixest") # For fixed effects Poisson regression
library(fixest)

# Set the working directory to where the script is. This will allow all csv files
# to be read in properly if they are kept together in the same folder.
setwd(dirname(rstudioapi::getSourceEditorContext()$path))

# Data important and prep -------------------------------------------------

BasicBankData <- read.csv("1893BankDirectory.csv", na.strings=c(""))
BasicBankData[sapply(BasicBankData, is.integer)] <- sapply(BasicBankData[sapply(BasicBankData, is.integer)], as.numeric)

# CountyID originally came in as character due to "." in some cells.
# Change it to double
BasicBankData$CountyID <- as.double(BasicBankData$CountyID)

# Change Clearinghouse and ClearinghouseCity to Boolean
BasicBankData$Clearinghouse <- ifelse(BasicBankData$Clearinghouse=="Yes",1,0)
BasicBankData$ClearinghouseCity <- ifelse(BasicBankData$ClearinghouseCity=="Yes",1,0)

BasicBankData$Clearinghouse <- as.logical(BasicBankData$Clearinghouse)
BasicBankData$ClearinghouseCity <- as.logical(BasicBankData$ClearinghouseCity)

# # Read in data frame on banks that suspended in 1893
SuspendedBanks <- read.csv("1893SuspendedBanks.csv", na.strings=c(""))
SuspendedBanks[sapply(SuspendedBanks, is.integer)] <- sapply(SuspendedBanks[sapply(SuspendedBanks, is.integer)], as.numeric)

# Clean up SuspendedBanks
SuspendedBanks <- SuspendedBanks[c("BankID", "CityID", "Type3", "DateClosed", "DateReopened", "Assets", "Liabilities", "LGD")]

# Changing date from character to date, make sure to get 1893 full year.
SuspendedBanks$DateClosed <- as.Date(SuspendedBanks$DateClosed, "%m/%d/%Y")
SuspendedBanks$DateReopened <- as.Date(SuspendedBanks$DateReopened, "%m/%d/%Y")

# Remove suspended banks with NA for BankID; without this problems
# with matching later
SuspendedBanks <- SuspendedBanks %>%
  drop_na("BankID")

# Read in County Census Data
CountyCensusData <- read.csv("Haines1890Census.csv", na.strings=c(""))
CountyCensusData[sapply(CountyCensusData, is.integer)] <- sapply(CountyCensusData[sapply(CountyCensusData, is.integer)], as.numeric)


# Only retain necessary census variables
CountyCensusData <- CountyCensusData[c("CountyID", "totpop", "urb890", "urb25", "farmout", "mfgout")]

# Read in City Population data
CityPopulations <- read.csv("1890CityPopulations.csv", na.strings=c(""))
CityPopulations[sapply(CityPopulations, is.integer)] <- sapply(CityPopulations[sapply(CityPopulations, is.integer)], as.numeric)


# Clean up CityPopulations
CityPopulations <- dplyr::rename(CityPopulations, CityPop = "Population")

CityPopulations <- CityPopulations[c("CityID", "CityPop")]

# Read in State Deposit Decline data
StateDepositDeclines <- read.csv("StateDepositDeclines.csv", na.strings=c(""))

StateDepositDeclines <- StateDepositDeclines[c("State", "StateDepositDecline")]

# Read in NYC Clearinghouse Membership
NYCCH <- read.csv("NYCHBankIDs.csv", na.strings=c(""))
NYCCH[sapply(NYCCH, is.integer)] <- sapply(NYCCH[sapply(NYCCH, is.integer)], as.numeric)

# Creation of Core Variables ----------------------------------------------

# Join Suspended data to core data.
BankData <- left_join(BasicBankData, SuspendedBanks, by=c("BankID"="BankID"))

# Join StateDepositDeclines to core data
BankData <- left_join(BankData, StateDepositDeclines, by="State")

# Create a variable for whether or not a bank suspended.
BankData$Suspended <- BankData$BankID %in% SuspendedBanks$BankID

# Create a variable for whether or not a NYC bank is a member of the Clearinghouse.
BankData$NYCHMember <- BankData$BankID %in% NYCCH$BankID

# Create a variable for whether or not a bank serves as a correspondent.
BankData$ServesasCorrespondent <- BankData$BankID %in% 
  c(BankData$Correspondent1BankID, BankData$Correspondent2BankID,
    BankData$Correspondent3BankID, BankData$Correspondent4BankID,
    BankData$Correspondent5BankID, BankData$Correspondent6BankID)

# Create a variable for whether a bank's correspondent is a NYCH member.
# Part 1: variable for each column with a correspondent in it.
BankData$Correspondent1NYCH <- BankData$Correspondent1BankID %in%
  NYCCH$BankID
BankData$Correspondent2NYCH <- BankData$Correspondent2BankID %in%
  NYCCH$BankID
BankData$Correspondent3NYCH <- BankData$Correspondent3BankID %in%
  NYCCH$BankID
BankData$Correspondent4NYCH <- BankData$Correspondent4BankID %in%
  NYCCH$BankID
BankData$Correspondent5NYCH <- BankData$Correspondent5BankID %in%
  NYCCH$BankID
BankData$Correspondent6NYCH <- BankData$Correspondent6BankID %in%
  NYCCH$BankID

# Part 2: variable for if any correspondent is a NYCH member.
BankData$CorrespondentInNYCH <- ifelse(BankData$Correspondent1NYCH == TRUE | 
                                            BankData$Correspondent1NYCH == TRUE | 
                                            BankData$Correspondent1NYCH == TRUE | 
                                            BankData$Correspondent1NYCH == TRUE | 
                                            BankData$Correspondent1NYCH == TRUE | 
                                            BankData$Correspondent1NYCH == TRUE, TRUE, FALSE)

# Create a variable for whether a bank's correspondent suspended.

# Part 1: variable for each column with a correspondent in it.
BankData$Correspondent1Suspended <- BankData$Correspondent1BankID %in%
  SuspendedBanks$BankID
BankData$Correspondent2Suspended <- BankData$Correspondent2BankID %in%
  SuspendedBanks$BankID
BankData$Correspondent3Suspended <- BankData$Correspondent3BankID %in%
  SuspendedBanks$BankID
BankData$Correspondent4Suspended <- BankData$Correspondent4BankID %in%
  SuspendedBanks$BankID
BankData$Correspondent5Suspended <- BankData$Correspondent5BankID %in%
  SuspendedBanks$BankID
BankData$Correspondent6Suspended <- BankData$Correspondent6BankID %in%
  SuspendedBanks$BankID

# Part 2: variable for if any correspondent suspended.
BankData$CorrespondentSuspended <- ifelse(BankData$Correspondent1Suspended == TRUE | 
                                          BankData$Correspondent2Suspended == TRUE | 
                                          BankData$Correspondent3Suspended == TRUE | 
                                          BankData$Correspondent4Suspended == TRUE | 
                                          BankData$Correspondent5Suspended == TRUE | 
                                          BankData$Correspondent6Suspended == TRUE, TRUE, FALSE)



# Part 3: variable for the number of correspondents suspended.

BankData$NumberofCorrespondentsSuspended <- NA

BankData$NumberofCorrespondentsSuspended <- rowSums(BankData[,c("Correspondent1Suspended", 
                                                                "Correspondent2Suspended", 
                                                                "Correspondent3Suspended", 
                                                                "Correspondent4Suspended", 
                                                                "Correspondent5Suspended", 
                                                                "Correspondent6Suspended")])



# Create a variable for only prior suspensions - CorrespondentSuspendedPrior

# Note: only the second version of tihs variable is used in the paper tables - 
# the version that excludes closure prior to April 21

SuspendedBanksFullData1 <- BankData %>%
  dplyr::filter(Suspended==TRUE)

SuspendedBanksFullData1$CorrespondentSuspendedPrior <- NA
SuspendedBanksFullData1$tmpCorr1Suspended <- NA
SuspendedBanksFullData1$tmpCorr2Suspended <- NA
SuspendedBanksFullData1$tmpCorr3Suspended <- NA
SuspendedBanksFullData1$tmpCorr4Suspended <- NA
SuspendedBanksFullData1$tmpCorr5Suspended <- NA
SuspendedBanksFullData1$tmpCorr6Suspended <- NA


for(i in 1:nrow(SuspendedBanksFullData1)){
  id <- SuspendedBanksFullData1$BankID[i]
  tmpDateClosed <- SuspendedBanksFullData1$DateClosed[i]
  tmpSuspendedPrior <- SuspendedBanksFullData1 %>% dplyr::filter(DateClosed <= tmpDateClosed)
  
  # Create temporary variables for whether each of six correspondents suspended for each bank.
  SuspendedBanksFullData1$tmpCorr1Suspended[i] <- SuspendedBanksFullData1$Correspondent1BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpCorr2Suspended[i] <- SuspendedBanksFullData1$Correspondent2BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpCorr3Suspended[i] <- SuspendedBanksFullData1$Correspondent3BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpCorr4Suspended[i] <- SuspendedBanksFullData1$Correspondent4BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpCorr5Suspended[i] <- SuspendedBanksFullData1$Correspondent5BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpCorr6Suspended[i] <- SuspendedBanksFullData1$Correspondent6BankID[i] %in%
    tmpSuspendedPrior$BankID
}

SuspendedBanksFullData1$CorrespondentSuspendedPrior <- ifelse(SuspendedBanksFullData1$tmpCorr1Suspended == TRUE | 
                                                 SuspendedBanksFullData1$tmpCorr2Suspended == TRUE | 
                                                 SuspendedBanksFullData1$tmpCorr3Suspended == TRUE | 
                                                 SuspendedBanksFullData1$tmpCorr4Suspended == TRUE | 
                                                 SuspendedBanksFullData1$tmpCorr5Suspended == TRUE | 
                                                 SuspendedBanksFullData1$tmpCorr6Suspended == TRUE, TRUE, FALSE)

# Keep only the relevant variable
CorrespondentSuspendedPrior <- SuspendedBanksFullData1[,c("BankID", "CorrespondentSuspendedPrior")]

# Join these values into BankData, replace NAs
BankData <- left_join(BankData, CorrespondentSuspendedPrior, by="BankID")
BankData$CorrespondentSuspendedPrior[is.na(BankData$CorrespondentSuspendedPrior)] <- BankData$CorrespondentSuspended[is.na(BankData$CorrespondentSuspendedPrior)]

# Create a variable for the number of correspondents suspended prior.
BankData$NumberofCorrespondentsSuspendedPrior <- BankData$NumberofCorrespondentsSuspended*BankData$CorrespondentSuspendedPrior

# Create a variable for the total number of correspondents a bank has
BankData$Correspondents <- rowSums(!is.na(BankData[,c("Correspondent1", "Correspondent2", "Correspondent3", "Correspondent4", "Correspondent5", "Correspondent6")]))

# Create a variable for the fraction of correspondents suspended prior.
BankData$FractionofCorrespondentsSuspendedPrior <- BankData$NumberofCorrespondentsSuspendedPrior/BankData$Correspondents

### Second version of correspondent suspension variable: Only correspondent suspensions after April 21.

# Part 1: variable for each column with a correspondent in it.
BankData$Correspondent1Suspended2 <- BankData$Correspondent1BankID %in%
  na.omit(SuspendedBanks[SuspendedBanks$DateClosed > '1893-04-21',]$BankID)
BankData$Correspondent2Suspended2 <- BankData$Correspondent2BankID %in%
  na.omit(SuspendedBanks[SuspendedBanks$DateClosed > '1893-04-21',]$BankID)
BankData$Correspondent3Suspended2 <- BankData$Correspondent3BankID %in%
  na.omit(SuspendedBanks[SuspendedBanks$DateClosed > '1893-04-21',]$BankID)
BankData$Correspondent4Suspended2 <- BankData$Correspondent4BankID %in%
  na.omit(SuspendedBanks[SuspendedBanks$DateClosed > '1893-04-21',]$BankID)
BankData$Correspondent5Suspended2 <- BankData$Correspondent5BankID %in%
  na.omit(SuspendedBanks[SuspendedBanks$DateClosed > '1893-04-21',]$BankID)
BankData$Correspondent6Suspended2 <- BankData$Correspondent6BankID %in%
  na.omit(SuspendedBanks[SuspendedBanks$DateClosed > '1893-04-21',]$BankID)

# Part 2: variable for if any correspondent suspended.
BankData$CorrespondentSuspended2 <- ifelse(BankData$Correspondent1Suspended2 == TRUE | 
                                             BankData$Correspondent2Suspended2 == TRUE | 
                                             BankData$Correspondent3Suspended2 == TRUE | 
                                             BankData$Correspondent4Suspended2 == TRUE | 
                                             BankData$Correspondent5Suspended2 == TRUE | 
                                             BankData$Correspondent6Suspended2 == TRUE, TRUE, FALSE)

# Second version of CorrespondentSuspendedPrior - only after April 21
SuspendedBanksFullData2 <- BankData %>%
  dplyr::filter(Suspended==TRUE & DateClosed > '1893-04-21')

SuspendedBanksFullData2$CorrespondentSuspendedPrior <- NA
SuspendedBanksFullData2$tmpCorr1Suspended <- NA
SuspendedBanksFullData2$tmpCorr2Suspended <- NA
SuspendedBanksFullData2$tmpCorr3Suspended <- NA
SuspendedBanksFullData2$tmpCorr4Suspended <- NA
SuspendedBanksFullData2$tmpCorr5Suspended <- NA
SuspendedBanksFullData2$tmpCorr6Suspended <- NA

for(i in 1:nrow(SuspendedBanksFullData2)){
  id <- SuspendedBanksFullData2$BankID[i]
  tmpDateClosed <- SuspendedBanksFullData2$DateClosed[i]
  tmpSuspendedPrior <- SuspendedBanksFullData2 %>% dplyr::filter(DateClosed <= tmpDateClosed)
  
  # Create temporary variables for whether each of six correspondents suspended for each bank.
  SuspendedBanksFullData2$tmpCorr1Suspended[i] <- SuspendedBanksFullData2$Correspondent1BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData2$tmpCorr2Suspended[i] <- SuspendedBanksFullData2$Correspondent2BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData2$tmpCorr3Suspended[i] <- SuspendedBanksFullData2$Correspondent3BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData2$tmpCorr4Suspended[i] <- SuspendedBanksFullData2$Correspondent4BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData2$tmpCorr5Suspended[i] <- SuspendedBanksFullData2$Correspondent5BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData2$tmpCorr6Suspended[i] <- SuspendedBanksFullData2$Correspondent6BankID[i] %in%
    tmpSuspendedPrior$BankID
}

SuspendedBanksFullData2$CorrespondentSuspendedPrior2 <- ifelse(SuspendedBanksFullData2$tmpCorr1Suspended == TRUE | 
                                                                SuspendedBanksFullData2$tmpCorr2Suspended == TRUE | 
                                                                SuspendedBanksFullData2$tmpCorr3Suspended == TRUE | 
                                                                SuspendedBanksFullData2$tmpCorr4Suspended == TRUE | 
                                                                SuspendedBanksFullData2$tmpCorr5Suspended == TRUE | 
                                                                SuspendedBanksFullData2$tmpCorr6Suspended == TRUE, TRUE, FALSE)

# Keep only the relevant variable
CorrespondentSuspendedPrior2 <- SuspendedBanksFullData2[,c("BankID", "CorrespondentSuspendedPrior2")]

# Join these values into BankData, replace NAs
BankData <- left_join(BankData, CorrespondentSuspendedPrior2, by="BankID")
BankData$CorrespondentSuspendedPrior2[is.na(BankData$CorrespondentSuspendedPrior2)] <- BankData$CorrespondentSuspended2[is.na(BankData$CorrespondentSuspendedPrior2)]

# Second version of the variable for the number of correspondents suspended prior.
BankData$NumberofCorrespondentsSuspendedPrior2 <- BankData$NumberofCorrespondentsSuspended*BankData$CorrespondentSuspendedPrior2

# Create a variable for the fraction of correspondents suspended prior.
BankData$FractionofCorrespondentsSuspendedPrior2 <- BankData$NumberofCorrespondentsSuspendedPrior2/BankData$Correspondents

# Create a variable with only in-state correspondent failures. #Takes 25-30 min
BankData$InStateCorrespondent1Suspended <- NA
BankData$InStateCorrespondent2Suspended <- NA
BankData$InStateCorrespondent3Suspended <- NA
BankData$InStateCorrespondent4Suspended <- NA
BankData$InStateCorrespondent5Suspended <- NA
BankData$InStateCorrespondent6Suspended <- NA
BankData$InStateCorrespondentSuspended <- NA

for(i in 1:nrow(BankData)){
  id <- BankData$BankID[i]
  bankstate <- BankData$State[i]
  tmp <- BankData %>% dplyr::filter(State == bankstate & Suspended == TRUE)
  BankData$InStateCorrespondent1Suspended[i] <- BankData$Correspondent1BankID[i] %in%
    tmp$BankID
  BankData$InStateCorrespondent2Suspended[i] <- BankData$Correspondent2BankID[i] %in%
    tmp$BankID
  BankData$InStateCorrespondent3Suspended[i] <- BankData$Correspondent3BankID[i] %in%
    tmp$BankID
  BankData$InStateCorrespondent4Suspended[i] <- BankData$Correspondent4BankID[i] %in%
    tmp$BankID
  BankData$InStateCorrespondent5Suspended[i] <- BankData$Correspondent5BankID[i] %in%
    tmp$BankID
  BankData$InStateCorrespondent6Suspended[i] <- BankData$Correspondent6BankID[i] %in%
    tmp$BankID
  
  BankData$InStateCorrespondentSuspended[i] <- ifelse(BankData$InStateCorrespondent1Suspended[i] == TRUE | 
                                              BankData$InStateCorrespondent2Suspended[i] == TRUE | 
                                              BankData$InStateCorrespondent3Suspended[i] == TRUE | 
                                              BankData$InStateCorrespondent4Suspended[i] == TRUE | 
                                              BankData$InStateCorrespondent5Suspended[i] == TRUE | 
                                              BankData$InStateCorrespondent6Suspended[i] == TRUE, TRUE, FALSE)
}

###  Now need to restrict this to only prior suspensions. 
# Create a variable for only prior in-state suspensions - InStateCorrespondentSuspendedPrior
SuspendedBanksFullData1 <- BankData %>%
  dplyr::filter(Suspended==TRUE)

SuspendedBanksFullData1$InStateCorrespondentSuspendedPrior <- NA
SuspendedBanksFullData1$tmpInStateCorr1Suspended <- NA
SuspendedBanksFullData1$tmpInStateCorr2Suspended <- NA
SuspendedBanksFullData1$tmpInStateCorr3Suspended <- NA
SuspendedBanksFullData1$tmpInStateCorr4Suspended <- NA
SuspendedBanksFullData1$tmpInStateCorr5Suspended <- NA
SuspendedBanksFullData1$tmpInStateCorr6Suspended <- NA

for(i in 1:nrow(SuspendedBanksFullData1)){
  id <- SuspendedBanksFullData1$BankID[i]
  bankstate <- SuspendedBanksFullData1$State[i]
  tmpDateClosed <- SuspendedBanksFullData1$DateClosed[i]
  tmpSuspendedPrior <- SuspendedBanksFullData1 %>% dplyr::filter(State == bankstate & DateClosed <= tmpDateClosed)
  
  # Create temporary variables for whether each of six correspondents suspended for each bank.
  SuspendedBanksFullData1$tmpInStateCorr1Suspended[i] <- SuspendedBanksFullData1$Correspondent1BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpInStateCorr2Suspended[i] <- SuspendedBanksFullData1$Correspondent2BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpInStateCorr3Suspended[i] <- SuspendedBanksFullData1$Correspondent3BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpInStateCorr4Suspended[i] <- SuspendedBanksFullData1$Correspondent4BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpInStateCorr5Suspended[i] <- SuspendedBanksFullData1$Correspondent5BankID[i] %in%
    tmpSuspendedPrior$BankID
  SuspendedBanksFullData1$tmpInStateCorr6Suspended[i] <- SuspendedBanksFullData1$Correspondent6BankID[i] %in%
    tmpSuspendedPrior$BankID
}

SuspendedBanksFullData1$InStateCorrespondentSuspendedPrior <- ifelse(SuspendedBanksFullData1$tmpInStateCorr1Suspended == TRUE | 
                                                                SuspendedBanksFullData1$tmpInStateCorr2Suspended == TRUE | 
                                                                SuspendedBanksFullData1$tmpInStateCorr3Suspended == TRUE | 
                                                                SuspendedBanksFullData1$tmpInStateCorr4Suspended == TRUE | 
                                                                SuspendedBanksFullData1$tmpInStateCorr5Suspended == TRUE | 
                                                                SuspendedBanksFullData1$tmpInStateCorr6Suspended == TRUE, TRUE, FALSE)




# Keep only the relevant variable
InStateCorrespondentSuspendedPrior <- SuspendedBanksFullData1[,c("BankID", "InStateCorrespondentSuspendedPrior")]

# Join these values into BankData, replace NAs
BankData <- left_join(BankData, InStateCorrespondentSuspendedPrior, by="BankID")
BankData$InStateCorrespondentSuspendedPrior[is.na(BankData$InStateCorrespondentSuspendedPrior)] <- BankData$InStateCorrespondentSuspended[is.na(BankData$InStateCorrespondentSuspendedPrior)]

# Create a variable for the number of non-NYC correspondents a bank has

# First, get NYC banks
NYCBanks <- BankData$BankID[BankData$City == "New York"]

# Then, count NYC correspondents for each bank
BankData$NYCCorrespondents <- NA
for(i in 1:nrow(BankData)){
  BankData$NYCCorrespondents[i] <- sum(BankData$Correspondent1BankID[i] %in% NYCBanks) + 
  sum(BankData$Correspondent2BankID[i] %in% NYCBanks) + 
  sum(BankData$Correspondent3BankID[i] %in% NYCBanks) + 
  sum(BankData$Correspondent4BankID[i] %in% NYCBanks) + 
  sum(BankData$Correspondent5BankID[i] %in% NYCBanks) + 
  sum(BankData$Correspondent6BankID[i] %in% NYCBanks)
}

# Then, get non-NYC Correspondents
BankData$NonNYCCorrespondents <- BankData$Correspondents - BankData$NYCCorrespondents

# Create a variable for whether a bank has correspondents in Chicago or St. Louis (other central reserve cities)
OtherCentralReserveBanks <- BankData$BankID[BankData$CityState == "Saint Louis, MO" | BankData$CityState == "Chicago, IL"]
BankData$OtherCentralReserveCorrespondents <- NA
for(i in 1:nrow(BankData)){
  BankData$OtherCentralReserveCorrespondents[i] <- sum(BankData$Correspondent1BankID[i] %in% OtherCentralReserveBanks) + 
    sum(BankData$Correspondent2BankID[i] %in% OtherCentralReserveBanks) + 
    sum(BankData$Correspondent3BankID[i] %in% OtherCentralReserveBanks) + 
    sum(BankData$Correspondent4BankID[i] %in% OtherCentralReserveBanks) + 
    sum(BankData$Correspondent5BankID[i] %in% OtherCentralReserveBanks) + 
    sum(BankData$Correspondent6BankID[i] %in% OtherCentralReserveBanks)
}

# Create a variable for the average fraction of city suspended in a bank's correspondents' cities.
BankData$FractionofCorrespondentsCitiesSuspended <- NA
for(i in 1:nrow(BankData)){
  BankData$FractionofCorrespondentsCitiesSuspended[i] <- mean(c(BankData$FractionofCitySuspendedPrior[BankData$BankID==BankData$Correspondent1BankID[i]], 
         BankData$FractionofCitySuspendedPrior[BankData$BankID==BankData$Correspondent2BankID[i]],
         BankData$FractionofCitySuspendedPrior[BankData$BankID==BankData$Correspondent3BankID[i]], 
         BankData$FractionofCitySuspendedPrior[BankData$BankID==BankData$Correspondent4BankID[i]],
         BankData$FractionofCitySuspendedPrior[BankData$BankID==BankData$Correspondent5BankID[i]], 
         BankData$FractionofCitySuspendedPrior[BankData$BankID==BankData$Correspondent6BankID[i]]), na.rm = TRUE)
}


# Create a variable for the average deposit decline in a bank's correspondents states.
BankData$CorrespondentStateDepositDecline <- NA
for(i in 1:nrow(BankData)){
  BankData$CorrespondentStateDepositDecline[i] <- mean(c(BankData$StateDepositDecline[BankData$BankID==BankData$Correspondent1BankID[i]], 
                                                                BankData$StateDepositDecline[BankData$BankID==BankData$Correspondent2BankID[i]],
                                                                BankData$StateDepositDecline[BankData$BankID==BankData$Correspondent3BankID[i]], 
                                                                BankData$StateDepositDecline[BankData$BankID==BankData$Correspondent4BankID[i]],
                                                                BankData$StateDepositDecline[BankData$BankID==BankData$Correspondent5BankID[i]], 
                                                                BankData$StateDepositDecline[BankData$BankID==BankData$Correspondent6BankID[i]]), na.rm = TRUE)
}

# Create a variable for the total number of respondents a bank has.
BankData <- BankData %>%
  group_by(BankID) %>%
  mutate(Respondents = sum(BankData$Correspondent1BankID %in% BankID) + 
           sum(BankData$Correspondent2BankID %in% BankID) + 
           sum(BankData$Correspondent3BankID %in% BankID) + 
           sum(BankData$Correspondent4BankID %in% BankID) + 
           sum(BankData$Correspondent5BankID %in% BankID) + 
           sum(BankData$Correspondent6BankID %in% BankID))

# Creating Pre and Post NY Suspension variables

# Pre NY Suspensions - only suspensions before August 3rd are true, all others false
BankData$PreNYSuspensions <- ifelse(BankData$DateClosed < as.Date("1893/08/03"), TRUE, FALSE)
BankData$PreNYSuspensions[is.na(BankData$PreNYSuspensions)] <- FALSE

# Pre NY Suspensions - only suspensions on or after August 3rd are true, all others false
BankData$PostNYSuspensions <- ifelse(BankData$DateClosed >= as.Date("1893/08/03"), TRUE, FALSE)
BankData$PostNYSuspensions[is.na(BankData$PostNYSuspensions)] <- FALSE

# Creating the Suspended and Reopened/Closed Permanently variables.
BankData$SuspendedandReopened <- ifelse(BankData$Suspended == TRUE & !is.na(BankData$DateReopened), TRUE, FALSE)
BankData$ClosedPermanently <- ifelse(BankData$Suspended == TRUE & is.na(BankData$DateReopened), TRUE, FALSE)

sum(BankData$SuspendedandReopened)
sum(BankData$ClosedPermanently)

# Create a variable for the number of failed respondents that a bank has.

# This takes about 20 minutes to run on my computer.
BankData$FailedRespondents <- NA
for(i in seq_along(BankData$BankID)){
  id <- BankData$BankID[i]
  tmp <- BankData %>% dplyr::filter(c(Correspondent1BankID == id |
                                    Correspondent2BankID == id |
                                    Correspondent3BankID == id |
                                    Correspondent4BankID == id |
                                    Correspondent5BankID == id |
                                    Correspondent6BankID == id)) %>% dplyr::select(BankID) %>% unique()
  BankData[i,]$FailedRespondents <- tmp$BankID %in% SuspendedBanks$BankID %>% sum()
  if(i %% 100 == 0){
    print(glue::glue("Current iteration: {i}\n\n"))
}
}

# Create a variable for the average state deposit decline among a bank's respondents.
BankData$StateDepositDeclinesAmongRespondents <- NA

for(i in 1:nrow(BankData)){
  id <- BankData$BankID[i]
  BankData[i,]$StateDepositDeclinesAmongRespondents <- 
    BankData %>% dplyr::filter(c(Correspondent1BankID == id |
                                 Correspondent2BankID == id |
                                 Correspondent3BankID == id |
                                 Correspondent4BankID == id |
                                 Correspondent5BankID == id |
                                 Correspondent6BankID == id)) %>% 
    dplyr::group_by(StateDepositDecline) %>% 
    dplyr::select(StateDepositDecline) %>% mean()
}

BankData$StateDepositDeclinesAmongRespondents <- -1*(BankData$StateDepositDeclinesAmongRespondents)

## Get number of respondents for each failed bank that failed after (so we can exclude them) 

# This is outside of the loop. Get all values for only suspended banks.
SuspendedBanksFullData2 <- BankData %>%
  dplyr::filter(Suspended==TRUE)
SuspendedBanksFullData2$FailedRespondentsAfterClosure <- NA

# The loop. For all 560 elements of SuspendedBanksFullData2, tabulate the respondent failures after closure.
for(i in 1:nrow(SuspendedBanksFullData2)){
  id <- SuspendedBanksFullData2$BankID[i]
  tmpDateClosed <- SuspendedBanksFullData2$DateClosed[i]
  tmpSuspendedAfter <- SuspendedBanksFullData2 %>% dplyr::filter(DateClosed > tmpDateClosed)
  # The following gives me the BankIDs of other Suspended banks using BankID[i] as a correspondent in tmp
  tmp <- SuspendedBanksFullData2 %>% 
    dplyr::filter(c(Correspondent1BankID == id |
                      Correspondent2BankID == id |
                      Correspondent3BankID == id |
                      Correspondent4BankID == id |
                      Correspondent5BankID == id |
                      Correspondent6BankID == id)) %>% 
    dplyr::select(BankID) %>% 
    unique()
  SuspendedBanksFullData2[i,]$FailedRespondentsAfterClosure <- tmp$BankID %in% tmpSuspendedAfter$BankID %>% sum()
}

# Keep only the relevant variable
FailedRespondentsAfterClosure <- SuspendedBanksFullData2[,c("BankID", "FailedRespondentsAfterClosure")]

# Join these values into BankData, replace NAs
BankData <- left_join(BankData, FailedRespondentsAfterClosure, by="BankID")
BankData$FailedRespondentsAfterClosure[is.na(BankData$FailedRespondentsAfterClosure)] <- 0

# Calculate the variable we really want: The number of respondents that failed prior to a bank's failure.
BankData$PriorFailedRespondents <- BankData$FailedRespondents - BankData$FailedRespondentsAfterClosure


# Create a variable for whether or not a bank had a respondent suspend.
BankData$RespondentSuspendedPrior <- ifelse(BankData$PriorFailedRespondents > 0, TRUE, FALSE)

# Create a variable for what fraction of a bank's respondents suspended.
BankData$FractionofRespondentsSuspendedPrior <- BankData$PriorFailedRespondents/BankData$Respondents
# Need to fix NAs from dividing by zero.
BankData$FractionofRespondentsSuspendedPrior[is.na(BankData$FractionofRespondentsSuspendedPrior)] <- 0

# Second version of number of failed respondents that a bank has.
# This takes about 20 minutes to run on my computer.
BankData$FailedRespondents2 <- NA
for(i in seq_along(BankData$BankID)){
  id <- BankData$BankID[i]
  tmp <- BankData %>% dplyr::filter(c(Correspondent1BankID == id |
                                        Correspondent2BankID == id |
                                        Correspondent3BankID == id |
                                        Correspondent4BankID == id |
                                        Correspondent5BankID == id |
                                        Correspondent6BankID == id)) %>% dplyr::select(BankID) %>% unique()
  BankData[i,]$FailedRespondents2 <- tmp$BankID %in% SuspendedBanks[SuspendedBanks$DateClosed > '1893-04-21',]$BankID %>% sum()
  if(i %% 100 == 0){
    print(glue::glue("Current iteration: {i}\n\n"))
  }
}

# Calculate the variable we really want: The number of respondents that failed prior to a bank's failure.
BankData$PriorFailedRespondents2 <- BankData$FailedRespondents2 - BankData$FailedRespondentsAfterClosure

# Create a variable for whether or not a bank had a respondent suspend.
BankData$RespondentSuspendedPrior2 <- ifelse(BankData$PriorFailedRespondents2 > 0, TRUE, FALSE)

# Create a variable for what fraction of a bank's respondents suspended.
BankData$FractionofRespondentsSuspendedPrior2 <- BankData$PriorFailedRespondents2/BankData$Respondents
# Need to fix NAs from dividing by zero.
BankData$FractionofRespondentsSuspendedPrior2[is.na(BankData$FractionofRespondentsSuspendedPrior2)] <- 0

# Create a variable for how many (other) suspensions occurred in a particular bank's city 
# Excludes its own suspension (if applicable)

BankData <- rename(BankData, CityID = CityID.x)

BankData <- BankData %>%
  group_by(BankID) %>%
  mutate(CitySuspensions = sum(SuspendedBanks$CityID %in% CityID))

# Exclude the bank's own suspension.
BankData$CitySuspensions <- ifelse(BankData$Suspended==TRUE, BankData$CitySuspensions-1, BankData$CitySuspensions)

# Number of a bank's city suspensions that were after its own suspension.
SuspendedBanksFullData3 <- BankData %>%
  dplyr::filter(Suspended==TRUE)
SuspendedBanksFullData3$CitySuspensionsAfterClosure <- NA

for(i in 1:nrow(SuspendedBanksFullData3)){
  tmpcityid <- SuspendedBanksFullData3$CityID[i]
  tmpDateClosed <- SuspendedBanksFullData3$DateClosed[i]
  tmpSuspendedAfter <- SuspendedBanksFullData3 %>% dplyr::filter(DateClosed > tmpDateClosed)
  # The following gives me the CityID of other Suspended banks using BankID[i] as a correspondent in tmp
  SuspendedBanksFullData3[i,]$CitySuspensionsAfterClosure <- sum(tmpSuspendedAfter$CityID == tmpcityid)
}

# Keep only the relevant variable
CitySuspensionsAfterClosure <- SuspendedBanksFullData3[,c("BankID", "CitySuspensionsAfterClosure")]

# Join these values into BankData, replace NAs
BankData <- left_join(BankData, CitySuspensionsAfterClosure, by="BankID")
BankData$CitySuspensionsAfterClosure[is.na(BankData$CitySuspensionsAfterClosure)] <- 0

# Calculate the variable we really want: The number of respondents that failed prior to a bank's failure.
BankData$PriorCitySuspensions <- BankData$CitySuspensions - BankData$CitySuspensionsAfterClosure

# Create a variable for how many banks are listed for each city.
BankData <- BankData %>% 
  group_by(BankID) %>% 
  mutate(CityBanks = sum(BankData$CityID %in% CityID))

# Create a variable for the fraction of city ever in suspension
BankData$FractionofCitySuspended <- BankData$CitySuspensions/BankData$CityBanks

# Fraction of City in Suspension (only counts prior suspensions if observation bank suspended)
BankData$FractionofCitySuspendedPrior <- BankData$PriorCitySuspensions/BankData$CityBanks

# Robustness Variables ----------------------------------------------------
# Generate bins for the LGD data.

BankData$LGDBinned <- NA

BankData$LGDBinned[BankData$LGD==0 & !is.na(BankData$LGD)] <- "0<=LGD<0.2"
BankData$LGDBinned[BankData$LGD>=.2 & BankData$LGD<.4 & !is.na(BankData$LGD)] <- "0.2<=LGD<0.4"
BankData$LGDBinned[BankData$LGD>=.4 & BankData$LGD<.6 & !is.na(BankData$LGD)] <- "0.4<=LGD<0.6"
BankData$LGDBinned[BankData$LGD>=.6 & BankData$LGD<.8 & !is.na(BankData$LGD)] <- "0.6<=LGD<0.8"
BankData$LGDBinned[BankData$LGD>=.8 & !is.na(BankData$LGD)] <- "0.8<=LGD<=1"

BankData$LGDBinned <- as.factor(BankData$LGDBinned)
BankData$LGDBinned <- ordered(BankData$LGDBinned, 
                              levels = c("0<=LGD<0.2", "0.2<=LGD<0.4", "0.4<=LGD<0.6", "0.6<=LGD<0.8", "0.8<=LGD<=1"))

#After variable creation, join in other two data sets.

BankData <- left_join(BankData, CountyCensusData, by="CountyID")

# Create variables for the urbanization rate (two measures)

BankData$urban1 <- BankData$urb890/BankData$totpop
BankData$urban2 <- BankData$urb25/BankData$totpop

# Create variable for the fraction of output from farming.

BankData$mfgout[is.na(BankData$mfgout)] <- 0
BankData$FarmtoTotalOutput <- BankData$farmout/(BankData$farmout + BankData$mfgout)

BankData <- left_join(BankData, CityPopulations, by="CityID")

# Calculate additional variables

BankData$Surplus[!is.na(BankData$Capital)] <- ifelse(is.na(BankData$Surplus), 0, BankData$Surplus)
BankData$UndivProfit[!is.na(BankData$Capital)] <- ifelse(is.na(BankData$UndivProfit), 0, BankData$UndivProfit)


BankData$FullCapital <- BankData$Capital + BankData$Surplus + BankData$UndivProfit

BankData$EquityQuality <- (BankData$Surplus + BankData$UndivProfit)/BankData$FullCapital

# Create log versions of the variables. If I do the transformation within the regression,
# then the code can't follow the variable names when creating custom standard errors
# for the marginal effects

BankData$logtotpop <- log(BankData$totpop)
BankData$logFullCapital <- log(BankData$FullCapital)
BankData$logRespondents <- log(BankData$Respondents+1)
BankData$logAssets <- log(BankData$Assets + 1)

BankData$NationalBank <- FALSE
BankData[BankData$Type1=="National",]$NationalBank <- TRUE

# Create manual version of all interaction terms used in robustness checks. 
# Without this the marginal effect coefficients and custom standard errors don't flow through.
BankData$CorrespondentSuspendedPriorxCorrespondents <- BankData$CorrespondentSuspendedPrior*BankData$Correspondents
BankData$RespondentSuspendedPriorxCorrespondents <- BankData$RespondentSuspendedPrior*BankData$Correspondents
BankData$FractionofRespondentsSuspendedPriorxCorrespondents <- BankData$FractionofRespondentsSuspendedPrior*BankData$Correspondents
BankData$CorrespondentSuspendedPriorxServesasCorrespondent <- BankData$CorrespondentSuspendedPrior*BankData$ServesasCorrespondent
BankData$CorrespondentSuspendedPriorxPriorCitySuspensions <- BankData$CorrespondentSuspendedPrior*BankData$PriorCitySuspensions
BankData$RespondentSuspendedPriorxPriorCitySuspensions <- BankData$RespondentSuspendedPrior*BankData$PriorCitySuspensions
BankData$FractionofRespondentsSuspendedPriorxPriorCitySuspensions <- BankData$FractionofRespondentsSuspendedPrior*BankData$PriorCitySuspensions
BankData$RespondentSuspendedPriorxRespondents <- BankData$RespondentSuspendedPrior*BankData$Respondents
BankData$RespondentSuspendedPriorxlogRespondents <- BankData$RespondentSuspendedPrior*BankData$logRespondents
BankData$CorrespondentSuspendedPriorxNonNYCCorrespondents <- BankData$CorrespondentSuspendedPrior*BankData$NonNYCCorrespondents
BankData$RespondentSuspendedPriorxNonNYCCorrespondents <- BankData$RespondentSuspendedPrior*BankData$NonNYCCorrespondents
BankData$FractionofRespondentsSuspendedPriorxNonNYCCorrespondents <- BankData$FractionofRespondentsSuspendedPrior*BankData$NonNYCCorrespondents
BankData$CorrespondentSuspendedPriorxOtherCentralReserveCorrespondents <- BankData$CorrespondentSuspendedPrior*BankData$OtherCentralReserveCorrespondents
BankData$CorrespondentSuspendedPriorxFractionofCorrespondentsCitiesSuspended <- BankData$CorrespondentSuspendedPrior*BankData$FractionofCorrespondentsCitiesSuspended
BankData$CorrespondentSuspendedPriorxCorrespondentStateDepositDecline <- BankData$CorrespondentSuspendedPrior*BankData$CorrespondentStateDepositDecline


BankData$CorrespondentSuspendedPrior2xCorrespondents <- BankData$CorrespondentSuspendedPrior2*BankData$Correspondents
BankData$RespondentSuspendedPrior2xRespondents <- BankData$RespondentSuspendedPrior2*BankData$Respondents
BankData$RespondentSuspendedPrior2xlogRespondents <- BankData$RespondentSuspendedPrior2*BankData$logRespondents
BankData$CorrespondentSuspendedPrior2xServesasCorrespondent <- BankData$CorrespondentSuspendedPrior2*BankData$ServesasCorrespondent
BankData$CorrespondentSuspendedPrior2xNonNYCCorrespondents <- BankData$CorrespondentSuspendedPrior2*BankData$NonNYCCorrespondents
BankData$RespondentSuspendedPrior2xNonNYCCorrespondents <- BankData$RespondentSuspendedPrior2*BankData$NonNYCCorrespondents
BankData$CorrespondentSuspendedPrior2xOtherCentralReserveCorrespondents <- BankData$CorrespondentSuspendedPrior2*BankData$OtherCentralReserveCorrespondents
BankData$CorrespondentSuspendedPrior2xPriorCitySuspensions <- BankData$CorrespondentSuspendedPrior2*BankData$PriorCitySuspensions
BankData$FractionofCorrespondentsSuspendedPrior2xPriorCitySuspensions <- BankData$FractionofCorrespondentsSuspendedPrior2*BankData$PriorCitySuspensions


# Fix typos in capitalization
BankData$State[BankData$State=="Ks"] <- "KS"
BankData$State[BankData$State=="Il"] <- "IL"

# Create Region variable for summary statistics table
BankData$Region <- NA
BankData$Region[BankData$State=="CT" | BankData$State=="ME" | BankData$State=="MA" | 
                  BankData$State=="NH" | BankData$State=="RI" | BankData$State=="VT"] <- "New Eng"
BankData$Region[BankData$State=="NY" | BankData$State=="NJ" | BankData$State=="PA" | 
                  BankData$State=="DE"] <- "Mid Atl"
BankData$Region[BankData$State=="OH" | BankData$State=="IN" | BankData$State=="IL" | 
                  BankData$State=="MO" | BankData$State=="MI" | BankData$State=="KS" | 
                  BankData$State=="KY" | BankData$State=="CO"] <- "West"
BankData$Region[BankData$State=="WI" | BankData$State=="MN" | BankData$State=="IA" | 
                  BankData$State=="NE" | BankData$State=="ND" | BankData$State=="MT" | 
                  BankData$State=="WY"] <- "NW"
BankData$Region[BankData$State=="MD" | BankData$State=="VA" | BankData$State=="WV" | 
                  BankData$State=="NC" | BankData$State=="SC" | BankData$State=="GA" | 
                  BankData$State=="FL" | BankData$State=="AL" | BankData$State=="MS" | 
                  BankData$State=="LA" | BankData$State=="TX" | BankData$State=="TN" | 
                  BankData$State=="AR"] <- "South"
BankData$Region[BankData$State=="CA" | BankData$State=="OR" | BankData$State=="NV" | 
                  BankData$State=="WA" | BankData$State=="ID"] <- "Pac"
BankData$Region[BankData$State=="AZ" | BankData$State=="Indian Territory" | BankData$State=="NM" | 
                  BankData$State=="UT" | BankData$State=="AK" | BankData$State=="OK"] <- "Ter"
BankData$Region <- as.factor(BankData$Region)
BankData$Region <- ordered(BankData$Region, levels = c("New Eng", "Mid Atl", "West", "NW", "South", "Pac", "Ter"))

BankData$FailureMonth <- NA
BankData$FailureMonth[BankData$DateClosed < "1893-06-01" & 
                        BankData$DateClosed > "1893-04-30" & !is.na(BankData$DateClosed)] <- "May"
BankData$FailureMonth[BankData$DateClosed < "1893-07-01" & 
                        BankData$DateClosed > "1893-05-31" & !is.na(BankData$DateClosed)] <- "June"
BankData$FailureMonth[BankData$DateClosed < "1893-08-01" & 
                        BankData$DateClosed > "1893-06-30" & !is.na(BankData$DateClosed)] <- "July"
BankData$FailureMonth[BankData$DateClosed < "1893-09-01" & 
                        BankData$DateClosed > "1893-07-31" & !is.na(BankData$DateClosed)] <- "Aug"
BankData$FailureMonth[BankData$DateClosed < "1893-10-01" & 
                        BankData$DateClosed > "1893-08-31" & !is.na(BankData$DateClosed)] <- "Sept"
BankData$FailureMonth[BankData$DateClosed < "1893-11-01" & 
                        BankData$DateClosed > "1893-09-30" & !is.na(BankData$DateClosed)] <- "Oct"
BankData$FailureMonth <- as.factor(BankData$FailureMonth)
BankData$FailureMonth <- ordered(BankData$FailureMonth, levels = c("May", "June", "July", "Aug", "Sept", "Oct"))

BankData$CentralReserveCity <- FALSE
BankData$CentralReserveCity[BankData$City=="New York" | BankData$City=="Saint Louis" | BankData$City=="Chicago"] <- TRUE

BankData$ReserveCity <- FALSE
BankData$ReserveCity[BankData$City=="Boston" & BankData$State=="MA"] <- TRUE
BankData$ReserveCity[BankData$City=="Philadelphia" & BankData$State=="PA"] <- TRUE
BankData$ReserveCity[BankData$City=="Baltimore" & BankData$State=="MD"] <- TRUE
BankData$ReserveCity[BankData$City=="Albany" & BankData$State=="NY"] <- TRUE
BankData$ReserveCity[BankData$City=="Brooklyn" & BankData$State=="NY"] <- TRUE
BankData$ReserveCity[BankData$City=="Pittsburgh" & BankData$State=="PA"] <- TRUE
BankData$ReserveCity[BankData$City=="Washington" & BankData$State=="DC"] <- TRUE
BankData$ReserveCity[BankData$City=="New Orleans" & BankData$State=="LA"] <- TRUE
BankData$ReserveCity[BankData$City=="Louisville" & BankData$State=="KY"] <- TRUE
BankData$ReserveCity[BankData$City=="Cincinnati" & BankData$State=="OH"] <- TRUE
BankData$ReserveCity[BankData$City=="Cleveland" & BankData$State=="OH"] <- TRUE
BankData$ReserveCity[BankData$City=="Detroit" & BankData$State=="MI"] <- TRUE
BankData$ReserveCity[BankData$City=="Milwaukee" & BankData$State=="WI"] <- TRUE
BankData$ReserveCity[BankData$City=="Des Moines" & BankData$State=="IA"] <- TRUE
BankData$ReserveCity[BankData$City=="Minneapolis" & BankData$State=="MN"] <- TRUE
BankData$ReserveCity[BankData$City=="Saint Paul" & BankData$State=="MN"] <- TRUE
BankData$ReserveCity[BankData$City=="Kansas City" & BankData$State=="KS"] <- TRUE
BankData$ReserveCity[BankData$City=="Kansas City" & BankData$State=="MO"] <- TRUE
BankData$ReserveCity[BankData$City=="Saint Joseph" & BankData$State=="MO"] <- TRUE
BankData$ReserveCity[BankData$City=="Lincoln" & BankData$State=="NE"] <- TRUE
BankData$ReserveCity[BankData$City=="Omaha" & BankData$State=="NE"] <- TRUE
BankData$ReserveCity[BankData$City=="San Francisco" & BankData$State=="CA"] <- TRUE

BankData$NonNYCReserveCity <- FALSE
BankData$NonNYCReserveCity[BankData$ReserveCity==TRUE] <- TRUE
BankData$NonNYCReserveCity[BankData$City=="Saint Louis" | BankData$City=="Chicago"] <- TRUE

BankData$ReserveCityStatus <- "Country"
BankData$ReserveCityStatus[BankData$ReserveCity==TRUE] <- "Reserve City"
BankData$ReserveCityStatus[BankData$CentralReserveCity==TRUE] <- "Central Reserve City"

BankData$ReserveCityStatus <- as.factor(BankData$ReserveCityStatus)
BankData$ReserveCityStatus <- ordered(BankData$ReserveCityStatus, levels = c("Country", "Reserve City", "Central Reserve City"))

BankData$FailedorReopened <- NA
BankData$FailedorReopened[BankData$SuspendedandReopened==TRUE] <- "Suspended and Reopened"
BankData$FailedorReopened[BankData$ClosedPermanently==TRUE] <- "Closed Permanently"

BankData$FailedorReopened <- as.factor(BankData$FailedorReopened)
BankData$FailedorReopened <- ordered(BankData$FailedorReopened, levels = c("Suspended and Reopened", "Closed Permanently"))

BankData$PreOrPostNYCHSuspension <- NA
BankData$PreOrPostNYCHSuspension[BankData$PreNYSuspensions==TRUE] <- "Suspended Before NYCH"
BankData$PreOrPostNYCHSuspension[BankData$PostNYSuspensions==TRUE] <- "Suspended After NYCH"

BankData$PreOrPostNYCHSuspension <- as.factor(BankData$PreOrPostNYCHSuspension)
BankData$PreOrPostNYCHSuspension <- ordered(BankData$PreOrPostNYCHSuspension, levels = c("Suspended Before NYCH", "Suspended After NYCH"))

### Save/read the final version of the dataset.
### This is here so as to not have to compile the dataset every session. Uncomment out save and/or load as needed

# saveRDS(BankData, file = "BankDataFinal.rds")

# BankData <- readRDS("BankDataFinal.rds")

# Summary Statistics and Plot --------------------------------------------

# Creating both panels of table 1
xtable(table(subset(BankData, 
             BankData$Correspondents > 0 & 
               (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed)) &
               !is.na(BankData$CorrespondentSuspendedPrior2) & 
               !is.na(BankData$PriorCitySuspensions) & 
               !is.na(BankData$Type1) & 
               !is.na(BankData$Clearinghouse) & 
               !is.na(BankData$ClearinghouseCity) & 
               !is.na(BankData$logtotpop) & 
               !is.na(BankData$FarmtoTotalOutput)
             )$Correspondents))

xtable(table(cut(subset(BankData, 
              ServesasCorrespondent==TRUE & 
               (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed)) &
               !is.na(BankData$RespondentSuspendedPrior2) & 
               !is.na(BankData$PriorCitySuspensions) & 
               !is.na(BankData$Type1) & 
               !is.na(BankData$Clearinghouse) & 
               !is.na(BankData$ClearinghouseCity) & 
               !is.na(BankData$logtotpop) & 
               !is.na(BankData$FarmtoTotalOutput)
)$Respondents, breaks = c(0,1,5,20,100,300,1224), dig.lab=5)))

# These two tables are manually combined into table 1 in the paper

# Creating Table 2
xtable(cbind(table(BankData$FailureMonth, BankData$Region), 
             table(BankData$FailureMonth, BankData$ReserveCityStatus)))

# Creating Table 5
xtable(table(BankData$FailureMonth, BankData$FailedorReopened))

# Create a correlation matrix, requested by referees. Not in final paper.
CorrelationData <- BankData[,c("Suspended", "CorrespondentSuspendedPrior", "RespondentSuspendedPrior", "PriorCitySuspensions", 
                               "logFullCapital", "CityPop", "Clearinghouse", "ClearinghouseCity", 
                               "totpop", "urban2", "FarmtoTotalOutput")]

stargazer(cor(CorrelationData, use="pairwise.complete.obs"), title="Correlation Matrix", out = "Correlation.tex")

CorrelationData2 <- BankData[,c("FullCapital", "CityPop", "Clearinghouse", "ClearinghouseCity", 
                               "totpop", "urban2", "FarmtoTotalOutput")]

stargazer(cor(CorrelationData2, use="pairwise.complete.obs"), title="Correlation Matrix")

# Creating Figure 1
SuspendedBanks$Week <- as.Date(cut(SuspendedBanks$DateClosed, "week"))

theme_set(theme_bw())

ggplot(SuspendedBanks, aes(x = Week)) + geom_bar() + 
  scale_x_date(date_breaks = "2 weeks", date_labels = "%d-%b")+
  theme(axis.title.x = element_blank(),
        axis.title.y = element_text(vjust = 2, size = 26),
        axis.text.x = element_text(angle = 90, vjust = 0, size = 20),
        axis.text.y = element_text(size = 20),
        panel.grid.minor = element_blank(),
        panel.grid.major = element_blank()) + 
  geom_vline(aes(xintercept = as.Date("1893-07-31")), linetype = 1, colour = "black") + 
  annotate("text", x = as.Date("1893-08-02"), y = 60, label="NYCH Suspension", hjust = 0, size = 7) + 
  ylab("Number of Bank Suspensions")

# Make sure to export the plot afterwards manually from RStudio

# Regressions and Tables --------------------------------------------------

# Create functions that takes a list of regressions as inputs, and
# outputs the marginal effects, custom standard errors, and p values

marginsfunction <- function(tablename) {
  tempAME <- list()
  for(reg in 1:length(tablename)){
    ## Need to create an element each time with reg number in the name
    tempAME[[reg]] <- summary(margins(tablename[[reg]]))$AME
    names(tablename[[reg]]$coefficients) <- gsub("TRUE","",names(tablename[[reg]]$coefficients))
    for(coeff in names(tempAME[[reg]])) {
      tablename[[reg]]$coefficients[[coeff]] <- tempAME[[reg]][[coeff]]
    }
  }
  return(tablename)
}

# Stargazer needs the standard errors from margins().
# This is a function to manually pull the standard errors from the margins() output.
marginsfunctionSE <- function(tablename) {
  tempSE <- list()
  for(reg in 1:length(tablename)){
    ## Need to create an element each time with reg number in the name
    names(tablename[[reg]]$coefficients) <- gsub("TRUE","",names(tablename[[reg]]$coefficients))
    tempSE[[reg]] <- summary(margins(tablename[[reg]]))$SE
    names(tempSE[[reg]]) <- gsub("Var_dydx_","",names(tempSE[[reg]]))
  }
  return(tempSE)
}

## Robust standard errors
# Stargazer needs the robust standard errors from margins().
# This is a function to manually pull the robust standard errors from the margins() output.
marginsfunctionSErobust <- function(tablename) {
  tempSE <- list()
  for(reg in 1:length(tablename)){
    ## Need to create an element each time with reg number in the name
    names(tablename[[reg]]$coefficients) <- gsub("TRUE","",names(tablename[[reg]]$coefficients))
    tempSE[[reg]] <- summary(margins(tablename[[reg]], vcov = vcovHC(tablename[[reg]], type = "HC0")))$SE
    names(tempSE[[reg]]) <- gsub("Var_dydx_","",names(tempSE[[reg]]))
  }
  return(tempSE)
}

# Stargazer is getting the p value wrong in the first column for some reason.
# This is a function to manually pull the p values from the margins() output.
marginsfunction_pval <- function(tablename) {
  temp_p <- list()
  for(reg in 1:length(tablename)){
    ## Need to create an element each time with reg number in the name
    names(tablename[[reg]]$coefficients) <- gsub("TRUE","",names(tablename[[reg]]$coefficients))
    temp_p[[reg]] <- setNames(summary(margins(tablename[[reg]]))$p, summary(margins(tablename[[reg]]))$factor)
  }
  return(temp_p)
}

###### Regression Tables

# Table 3 in Final Paper

# Note: this was table 1 in a previous version so the code references table 1 but this is table 3 in the final paper.

p1_1 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
                  Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
                family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p1_2 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
                  Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
                family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p1_3 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p1_4 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p1_5 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
                family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p1_6 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
                family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p1_7 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
                family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p1_8 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
                family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

table1 <- list(p1_1, p1_2, p1_3, p1_4, p1_5, p1_6, p1_7, p1_8)

depvarmean1 <- list(c("Mean of Dependent Variable", 
                    round(mean(model.frame(p1_1)$Suspended), digits = 3),
                    round(mean(model.frame(p1_2)$Suspended), digits = 3),
                    round(mean(model.frame(p1_3)$Suspended), digits = 3),
                    round(mean(model.frame(p1_4)$Suspended), digits = 3),
                    round(mean(model.frame(p1_5)$Suspended), digits = 3),
                    round(mean(model.frame(p1_6)$Suspended), digits = 3),
                    round(mean(model.frame(p1_7)$Suspended), digits = 3),
                    round(mean(model.frame(p1_8)$Suspended), digits = 3)))

table1marginal <- marginsfunction(table1)
table1marginalse <- marginsfunctionSErobust(table1)
table1marginal_pval <- marginsfunction_pval(table1)

custom_R2_p1 = list(c("Pseudo R-Squared", 
                   round(PseudoR2(p1_1, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(p1_2, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(p1_3, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(p1_4, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(p1_5, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(p1_6, "McKelveyZavoi"),digits = 2),
                   round(PseudoR2(p1_7, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(p1_8, "McKelveyZavoi"),digits = 2)))

stargazer(table1marginal,
          add.lines = c(depvarmean1, custom_R2_p1), keep.stat=("n"),
          column.labels = c("All Banks", "Banks with Respondents"),
          column.separate = c(4, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Bank Suspensions and the Role of Correspondents and Respondents (Marginal Effects)",
          se = table1marginalse,
          p = table1marginal_pval,
          out="Table3_Final.tex", header=FALSE, no.space=TRUE)

# Table 4 in Final Paper - code references previous table number again

p2_1 <- glm(PreNYSuspensions ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p2_2 <- glm(PreNYSuspensions ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p2_3 <- glm(PostNYSuspensions ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & PreNYSuspensions==FALSE))

p2_4 <- glm(PostNYSuspensions ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & PreNYSuspensions==FALSE))

p2_5 <- glm(PreNYSuspensions ~ RespondentSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p2_6 <- glm(PreNYSuspensions ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p2_7 <- glm(PostNYSuspensions ~ RespondentSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE & ServesasCorrespondent==TRUE))

p2_8 <- glm(PostNYSuspensions ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE & ServesasCorrespondent==TRUE))

table2 <- list(p2_1, p2_2, p2_3, p2_4, p2_5, p2_6, p2_7, p2_8)

depvarmean2 <- list(c("Mean of Dependent Variable", 
                      round(mean(model.frame(p2_1)$PreNYSuspensions), digits = 3),
                      round(mean(model.frame(p2_2)$PreNYSuspensions), digits = 3),
                      round(mean(model.frame(p2_3)$PostNYSuspensions), digits = 3),
                      round(mean(model.frame(p2_4)$PostNYSuspensions), digits = 3),
                      round(mean(model.frame(p2_5)$PreNYSuspensions), digits = 3),
                      round(mean(model.frame(p2_6)$PreNYSuspensions), digits = 3),
                      round(mean(model.frame(p2_7)$PostNYSuspensions), digits = 3),
                      round(mean(model.frame(p2_8)$PostNYSuspensions), digits = 3)))

table2marginal <- marginsfunction(table2)
table2marginalse <- marginsfunctionSErobust(table2)
table2marginal_pval <- marginsfunction_pval(table2)

custom_R2_p2 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(p2_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(p2_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(p2_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(p2_4, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(p2_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(p2_6, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(p2_7, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(p2_8, "McKelveyZavoi"),digits = 2)))

stargazer(table2marginal,
          add.lines = c(depvarmean2, custom_R2_p2), keep.stat=("n"),
          column.labels = c("Pre NYCH Suspension", "Post NYCH Suspension", "Pre NYCH Suspension", "Post NYCH Suspension"),
          column.separate = c(2, 2, 2, 2),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Bank Suspensions Before and After NYCH Suspension (Marginal Effects)",
          se = table2marginalse,
          p = table2marginal_pval,
          out="Table4_Final.tex", header=FALSE, no.space=TRUE)

# Table 6 in Final Paper - code references previous table number again

p3_1 <- glm(SuspendedandReopened ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
                Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
              family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p3_2 <- glm(ClosedPermanently ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
                Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
              family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p3_3 <- glm(SuspendedandReopened ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + 
                Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
              family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p3_4 <- glm(ClosedPermanently ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + 
                Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
              family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

p3_5 <- glm(SuspendedandReopened ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logAssets + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Correspondents > 0 & Suspended==TRUE & DateClosed > "1893-04-21"))

p3_6 <- glm(SuspendedandReopened ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + logAssets + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Suspended==TRUE & DateClosed > "1893-04-21"))

p3_7 <- lm(LGD ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logAssets + 
             Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
           data = subset(BankData, Suspended==TRUE & Type3=="National" & DateClosed > "1893-04-21"))

p3_8 <- polr(LGDBinned ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logAssets + 
               Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             method = c("probit"), data = subset(BankData, Suspended==TRUE & Type3=="National" & DateClosed > "1893-04-21"), Hess = TRUE)

table3 <- list(p3_1, p3_2, p3_3, p3_4, p3_5, p3_6)

depvarmean3 <- list(c("Mean of Dependent Variable", 
                      round(mean(model.frame(p3_1)$SuspendedandReopened), digits = 3),
                      round(mean(model.frame(p3_2)$ClosedPermanently), digits = 3),
                      round(mean(model.frame(p3_3)$SuspendedandReopened), digits = 3),
                      round(mean(model.frame(p3_4)$ClosedPermanently), digits = 3),
                      round(mean(model.frame(p3_5)$SuspendedandReopened), digits = 3),
                      round(mean(model.frame(p3_6)$SuspendedandReopened), digits = 3),
                      round(mean(model.frame(p3_7)$LGD), digits = 3),
                      ""))

table3marginal <- marginsfunction(table3)
table3marginalse <- marginsfunctionSErobust(table3)
table3marginal_pval <- marginsfunction_pval(table3)

# Pull values for linear model
names(p3_7$coefficients) <- gsub("TRUE","",names(p3_7$coefficients))
table3lmse <- coeftest(p3_7, vcov = vcovHC(p3_7, type = 'HC0'))[,2]
table3lm_p <- coeftest(p3_7, vcov = vcovHC(p3_7, type = 'HC0'))[,4]

# Pull values for ordered probit
names(p3_8$coefficients) <- gsub("TRUE","",names(p3_8$coefficients))
table3polrse <- coefficients(summary(p3_8), vcov = vcovHC(p3_8, type = "HC0"))[,2]
table3polr_p <- coeftest(p3_8)[,4] # from AER package

table3final <- append(table3marginal, list(p3_7, p3_8))
table3finalse <- append(table3marginalse, list(table3lmse, table3polrse))
table3final_pval <- append(table3marginal_pval, list(table3lm_p, table3polr_p))

custom_R2_table3 = list(c("Pseudo R-Squared", 
                                  round(PseudoR2(p3_1, "McKelveyZavoi"),digits = 2), 
                                  round(PseudoR2(p3_2, "McKelveyZavoi"),digits = 2), 
                                  round(PseudoR2(p3_3, "McKelveyZavoi"),digits = 2), 
                                  round(PseudoR2(p3_4, "McKelveyZavoi"),digits = 2), 
                                  round(PseudoR2(p3_5, "McKelveyZavoi"),digits = 2), 
                                  round(PseudoR2(p3_6, "McKelveyZavoi"),digits = 2), 
                                  "",
                                  round(PseudoR2(p3_8),digits = 2)))

stargazer(table3final,
          add.lines = c(depvarmean3, custom_R2_table3), keep.stat=c("rsq", "n"),
          column.labels = c("Reopened", "Did Not Reopen", "Reopened", "Did Not Reopen", "Reopened", "LGD (National Banks Only)"),
          column.separate = c(1, 1, 1, 1, 2, 2),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          se = table3finalse,
          p = table3final_pval,
          title = "Correspondent/Respondent Suspensions, Temporary vs Permanent Closures, and Losses to Equityholders",
          out="Table6_Final.tex", header=FALSE, no.space=TRUE)

# Weekly Bank Regressions -------------------------------------------------

WeeklyBS <- read.csv("NYWeeklyBalanceSheets.csv", na.strings=c(""))
WeeklyBS[sapply(WeeklyBS, is.integer)] <- sapply(WeeklyBS[sapply(WeeklyBS, is.integer)], as.numeric)

# Put everything in millions
WeeklyBS$Deposits2 <- WeeklyBS$Deposits/1000000
WeeklyBS$Loans2 <- WeeklyBS$Loans/1000000
WeeklyBS$Specie2 <- WeeklyBS$Specie/1000000
WeeklyBS$AssetsofRespondentsinSuspension2 <- WeeklyBS$AssetsofRespondentsinSuspension/1000000

WeeklyBS$Date <- as.Date(WeeklyBS$Date, "%m-%d-%Y")

# Weekly Balance Sheet Regressions - OLS in logs

weekly1_1 <- lm(log(Deposits2) ~ RespondentsinSuspension + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_2 <- lm(log(Loans2) ~ RespondentsinSuspension + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_3 <- lm(log(Specie2) ~ RespondentsinSuspension + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_4 <- lm(log(Deposits2) ~ AssetsofRespondentsinSuspension2 + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_5 <- lm(log(Loans2) ~ AssetsofRespondentsinSuspension2 + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_6 <- lm(log(Specie2) ~ AssetsofRespondentsinSuspension2 + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_7 <- lm(log(Deposits2) ~ FractionofRespondentsinSuspension + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_8 <- lm(log(Loans2) ~ FractionofRespondentsinSuspension + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_9 <- lm(log(Specie2) ~ FractionofRespondentsinSuspension + factor(Date) + factor(BankID), 
           data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0))

weekly1_1robust <- coeftest(weekly1_1, vcov = vcovHC(weekly1_1, type = 'HC0'))
weekly1_2robust <- coeftest(weekly1_2, vcov = vcovHC(weekly1_2, type = 'HC0'))
weekly1_3robust <- coeftest(weekly1_3, vcov = vcovHC(weekly1_3, type = 'HC0'))
weekly1_4robust <- coeftest(weekly1_4, vcov = vcovHC(weekly1_4, type = 'HC0'))
weekly1_5robust <- coeftest(weekly1_5, vcov = vcovHC(weekly1_5, type = 'HC0'))
weekly1_6robust <- coeftest(weekly1_6, vcov = vcovHC(weekly1_6, type = 'HC0'))
weekly1_7robust <- coeftest(weekly1_7, vcov = vcovHC(weekly1_7, type = 'HC0'))
weekly1_8robust <- coeftest(weekly1_8, vcov = vcovHC(weekly1_8, type = 'HC0'))
weekly1_9robust <- coeftest(weekly1_9, vcov = vcovHC(weekly1_9, type = 'HC0'))

# Weekly Balance Sheet Regressions - Poisson model with fixed effects

weekly1poisson_1 <- feglm(Deposits2 ~ RespondentsinSuspension | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_2 <- feglm(Loans2 ~ RespondentsinSuspension | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_3 <- feglm(Specie2 ~ RespondentsinSuspension | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_4 <- feglm(Deposits2 ~ AssetsofRespondentsinSuspension2 | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_5 <- feglm(Loans2 ~ AssetsofRespondentsinSuspension2 | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_6 <- feglm(Specie2 ~ AssetsofRespondentsinSuspension2 | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_7 <- feglm(Deposits2 ~ FractionofRespondentsinSuspension | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_8 <- feglm(Loans2 ~ FractionofRespondentsinSuspension | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1poisson_9 <- feglm(Specie2 ~ FractionofRespondentsinSuspension | Date + BankID, 
                          data = subset(WeeklyBS, WeeklyBS$TotalRespondents>0), vcov = "hetero")

weekly1_panelA <- list(weekly1_1robust, weekly1_2robust, weekly1_3robust)
weekly1_panelB <- list(weekly1_4robust, weekly1_5robust, weekly1_6robust)
weekly1_panelC <- list(weekly1_7robust, weekly1_8robust, weekly1_9robust)

weekly1poisson_panelA <- list(weekly1poisson_1, weekly1poisson_2, weekly1poisson_3)
weekly1poisson_panelB <- list(weekly1poisson_4, weekly1poisson_5, weekly1poisson_6)
weekly1poisson_panelC <- list(weekly1poisson_7, weekly1poisson_8, weekly1poisson_9)

BankNumbers <- list(c("Number of Banks", 57, 57, 57, 57, 57, 57))

depvarmean4 <- list(c("Mean of Dependent Variable", 
                      round(mean(exp(model.frame(weekly1_1)$"log(Deposits2)")), digits = 2),
                      round(mean(exp(model.frame(weekly1_2)$"log(Loans2)")), digits = 2),
                      round(mean(exp(model.frame(weekly1_3)$"log(Specie2)")), digits = 2),
                      round(mean(exp(model.frame(weekly1_1)$"log(Deposits2)")), digits = 2),
                      round(mean(exp(model.frame(weekly1_2)$"log(Loans2)")), digits = 2),
                      round(mean(exp(model.frame(weekly1_3)$"log(Specie2)")), digits = 2)))

# Table 7 in final paper - MUST BE PARTIALLY MANUALLY CREATED.

# Note: These commands create two copies of each set of three regressions, and temporarily
# mis-label the second copy as Poisson. The etable commands below create the .tex
# Poisson tables. The coefficients and standard errors needed to be copied and pasted
# onto these tables to overwrite columns 4-6 (the duplicate results)

stargazer(weekly1_panelA, weekly1_panelA, omit = c("Date", "BankID", "Constant"),
          column.labels = c("Linear Model", "Poisson Model"),
          column.separate = c(3, 3),
          add.lines = c(depvarmean4, BankNumbers), keep.stat=("n"),
          out="Weekly1_PanelA.tex", header=FALSE, no.space=TRUE)

stargazer(weekly1_panelB, weekly1_panelB, omit = c("Date", "BankID", "Constant"),
          column.labels = c("Linear Model", "Poisson Model"),
          column.separate = c(3, 3),
          add.lines = BankNumbers, keep.stat=("n"),
          out="Weekly1_PanelB.tex", header=FALSE, no.space=TRUE)

stargazer(weekly1_panelC, weekly1_panelC, omit = c("Date", "BankID", "Constant"),
          column.labels = c("Linear Model", "Poisson Model"),
          column.separate = c(3, 3),
          add.lines = BankNumbers, keep.stat=("n"),
          out="Weekly1_PanelC.tex", header=FALSE, no.space=TRUE)

# Create lyx table to copy coefficient/standard errors from.
etable(weekly1poisson_panelA, tex = TRUE)
etable(weekly1poisson_panelB, tex = TRUE)
etable(weekly1poisson_panelC, tex = TRUE)

# Need to manually add in the rows from Panels B and C into weekly1_panelA.tex, 
# and manually add the Panel names and dividing lines


# Weekly Stock Price Data

WeeklyStockPrice <- read.csv("StockPriceData.csv", na.strings=c(""))
WeeklyStockPrice[sapply(WeeklyStockPrice, is.integer)] <- sapply(WeeklyStockPrice[sapply(WeeklyStockPrice, is.integer)], as.numeric)


WeeklyStockPrice$Date <- as.Date(WeeklyStockPrice$Date, "%m-%d-%Y")


WeeklyStockPrice$RespondentClosed <- 0
WeeklyStockPrice[WeeklyStockPrice$ClosedRespondents > 0,]$RespondentClosed <- 1

WeeklyStockPrice$AssetsofRespondentsCurrentlyClosed2 <- WeeklyStockPrice$AssetsofRespondentsCurrentlyClosed/1000000


# Table 8 in Final Paper - Weekly Stock Price Regressions

weekly2_1 <- lm(NormalizedPriceFilled ~ RespondentClosed + factor(Date) + factor(BankID),
           data  = subset(WeeklyStockPrice, WeeklyStockPrice$TotalRespondents > 0))

weekly2_2 <- lm(NormalizedPriceFilled ~ FractionofRespondentsCurrentlyClosed + factor(Date) + factor(BankID),
           data  = subset(WeeklyStockPrice, WeeklyStockPrice$TotalRespondents > 0))

weekly2_1robust <- coeftest(weekly2_1, vcov = vcovHC(weekly2_1, type = 'HC0'))
weekly2_2robust <- coeftest(weekly2_2, vcov = vcovHC(weekly2_2, type = 'HC0'))

# Count distinct banks used in regression
n_distinct(WeeklyStockPrice[WeeklyStockPrice$TotalRespondents>0,]$BankID) #65

obs1 <- nobs(weekly2_1)/2
obs2 <- nobs(weekly2_2)/2

BankNumbers2 <- list(c("Number of Banks", 65, 65))
CustomObservations <- list(c("Observations", obs1, obs2))

stargazer(weekly2_1robust, weekly2_2robust, omit = c("Date", "BankID", "Constant"),
          column.labels = c("Dependent Variable: Bank Stock Price"),
          column.separate = c(2),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          add.lines = c(BankNumbers2, CustomObservations),
          omit.stat = ("all"),
          out="Table8_Final.tex", header=FALSE, no.space=TRUE)

#### This is the end of the code for producing the tables and figures used in the paper #####
#### The remainder of the code produces tables used in response to referee reports only #####
#### Some results from below tables are referenced in the paper however. #####

# Robustness Checks -------------------------------------------------------


# Condensed Robustness Check Tables

## Referee A Tables
# Robustness checks for All Banks sample (Referee A)

# Including the number of correspondents
r1_1 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + Correspondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r2_1 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + Correspondents + CorrespondentSuspendedPrior2xCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

# Including in-state correspondent indicators
r3_3 <- glm(Suspended ~ InStateCorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r3_5 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + InStateCorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

# Equity Quality
r6_2 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))



robustnessA1 <- list(r1_1, r2_1, r3_3, r3_5, r6_2)


robustnessA1marginal <- marginsfunction(robustnessA1)
robustnessA1marginalse <- marginsfunctionSErobust(robustnessA1)
robustnessA1marginal_pval <- marginsfunction_pval(robustnessA1)


custom_R2_rA1 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r1_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r2_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r3_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r3_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r6_2, "McKelveyZavoi"),digits = 2)))


stargazer(robustnessA1marginal, 
          add.lines = custom_R2_rA1, keep.stat=("n"),
          column.labels = c("All Banks"),
          column.separate = c(5),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Checks for Respondent Bank Regressions (All Banks)",
          se = robustnessA1marginalse,
          p = robustnessA1marginal_pval,
          out="RobustnessA1.tex", header=FALSE, no.space=TRUE)



# Robustness checks for Banks with Respondents sample (Referee A)

# Including the number of respondents
r8_1 <- glm(Suspended ~ RespondentSuspendedPrior2 + Respondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r8_2 <- glm(Suspended ~ RespondentSuspendedPrior2 + Respondents + RespondentSuspendedPrior2xRespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r8_3 <- glm(Suspended ~ RespondentSuspendedPrior2 + logRespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r8_4 <- glm(Suspended ~ RespondentSuspendedPrior2 + logRespondents + RespondentSuspendedPrior2xlogRespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

# Looking at state deposit declines among respondents
r12_1 <- glm(Suspended ~ RespondentSuspendedPrior2 + StateDepositDeclinesAmongRespondents + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r12_3 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + StateDepositDeclinesAmongRespondents + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

# Equity quality
r6_4 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r6_6 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))



robustnessA2 <- list(r8_1, r8_2, r8_3, r8_4, r12_1, r12_3, r6_4, r6_6)


robustnessA2marginal <- marginsfunction(robustnessA2)
robustnessA2marginalse <- marginsfunctionSErobust(robustnessA2)
robustnessA2marginal_pval <- marginsfunction_pval(robustnessA2)


custom_R2_rA2 = list(c("Pseudo R-Squared", 
                       round(PseudoR2(r8_1, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r8_2, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r8_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r8_4, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r12_1, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r12_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r6_4, "McKelveyZavoi"),digits = 2),
                       round(PseudoR2(r6_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustnessA2marginal, 
          add.lines = custom_R2_rA2, keep.stat=("n"),
          column.labels = c("Banks with Respondents"),
          column.separate = c(8),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Checks for Correspondent Bank Regressions (Banks with Respondents)",
          se = robustnessA2marginalse,
          p = robustnessA2marginal_pval,
          out="RobustnessA2.tex", header=FALSE, no.space=TRUE)





# Robustness checks for Two-Sided Risks
# Full Sample
r4_3 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + ServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r4_5 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + ServesasCorrespondent + CorrespondentSuspendedPrior2xServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

# Clearinghouse Cities Only
r5_3 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + ServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r5_5 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + ServesasCorrespondent + CorrespondentSuspendedPrior2xServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

# Clearinghouse Cities Only, National Banks Only
r5_6 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + ServesasCorrespondent + PriorCitySuspensions + 
               Clearinghouse + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r5_7 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + ServesasCorrespondent + CorrespondentSuspendedPrior2xServesasCorrespondent + PriorCitySuspensions + 
               Clearinghouse + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))


robustnessA3 <- list(r4_3, r4_5, r5_3, r5_5, r5_6, r5_7)


robustnessA3marginal <- marginsfunction(robustnessA3)
robustnessA3marginalse <- marginsfunctionSErobust(robustnessA3)
robustnessA3marginal_pval <- marginsfunction_pval(robustnessA3)


custom_R2_rA3 = list(c("Pseudo R-Squared", 
                       round(PseudoR2(r4_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r4_5, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r5_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r5_5, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r5_6, "McKelveyZavoi"),digits = 2),
                       round(PseudoR2(r5_7, "McKelveyZavoi"),digits = 2)))


stargazer(robustnessA3marginal, 
          add.lines = custom_R2_rA3, keep.stat=("n"),
          column.labels = c("All Banks", "Clearinghouse Cities Only", "Clearinghouse Cities, National Banks Only"),
          column.separate = c(2, 2, 2),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "One-Sided versus Two-Sided Risk",
          se = robustnessA3marginalse,
          p = robustnessA3marginal_pval,
          out="RobustnessA3.tex", header=FALSE, no.space=TRUE)

### Note: this table does not put the correct standard errors on the last column.
### Need to run summary(margins(r5_7)) to get the errors and enter them manually.





# Robustness Checks for Pre-NYCH vs Post-NYCH Suspension

# Other Central Reserve City Correspondents
r11_1 <- glm(PreNYSuspensions ~ CorrespondentSuspendedPrior2 + OtherCentralReserveCorrespondents + CorrespondentSuspendedPrior2xOtherCentralReserveCorrespondents + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r11_3 <- glm(PostNYSuspensions ~ CorrespondentSuspendedPrior2 + OtherCentralReserveCorrespondents + CorrespondentSuspendedPrior2xOtherCentralReserveCorrespondents + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & PreNYSuspensions==FALSE))

# Non-NYC Correspondents
r9_1 <- glm(PreNYSuspensions ~ CorrespondentSuspendedPrior2 + NonNYCCorrespondents + CorrespondentSuspendedPrior2xNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r9_3 <- glm(PostNYSuspensions ~ CorrespondentSuspendedPrior2 + NonNYCCorrespondents + CorrespondentSuspendedPrior2xNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & PreNYSuspensions==FALSE))

r10_1 <- glm(PreNYSuspensions ~ RespondentSuspendedPrior2 + NonNYCCorrespondents + RespondentSuspendedPrior2xNonNYCCorrespondents + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r10_3 <- glm(PostNYSuspensions ~ RespondentSuspendedPrior2 + NonNYCCorrespondents + RespondentSuspendedPrior2xNonNYCCorrespondents + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE & ServesasCorrespondent==TRUE))


robustnessA4 <- list(r11_1, r11_3, r9_1, r9_3, r10_1, r10_3)

robustnessA4marginal <- marginsfunction(robustnessA4)
robustnessA4marginalse <- marginsfunctionSErobust(robustnessA4)
robustnessA4marginal_pval <- marginsfunction_pval(robustnessA4)

custom_R2_rA4 = list(c("Pseudo R-Squared", 
                       round(PseudoR2(r11_1, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r11_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r9_1, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r9_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r10_1, "McKelveyZavoi"),digits = 2),
                       round(PseudoR2(r10_3, "McKelveyZavoi"),digits = 2)))

stargazer(robustnessA4marginal, 
          add.lines = custom_R2_rA4, keep.stat=("n"),
          column.labels = c("Pre NYCH", "Post NYCH", "Pre NYCH", "Post NYCH", "Pre NYCH", "Post NYCH"),
          column.separate = c(1, 1, 1, 1, 1, 1),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Checks for Pre- vs Post-NYCH Suspension",
          se = robustnessA4marginalse,
          p = robustnessA4marginal_pval,
          out="RobustnessA4.tex", header=FALSE, no.space=TRUE)



## Referee B Tables

# Robustness Checks for full sample (Referee B)

# Interaction with Prior City Suspensions, only one regression
r7_1 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + CorrespondentSuspendedPrior2xPriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r7_1b <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + FractionofCorrespondentsSuspendedPrior2xPriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

# Role of equity quality

r6_2 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r6_2b <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$Correspondents > 0 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r6_4 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r6_6 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))


robustnessB <- list(r7_1, r7_1b, r6_2, r6_2b, r6_4, r6_6)


robustnessBmarginal <- marginsfunction(robustnessB)
robustnessBmarginalse <- marginsfunctionSErobust(robustnessB)
robustnessBmarginal_pval <- marginsfunction_pval(robustnessB)


custom_R2_rB = list(c("Pseudo R-Squared", 
                       round(PseudoR2(r7_1, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r7_1b, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r6_2, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r6_2b, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r6_4, "McKelveyZavoi"),digits = 2),
                       round(PseudoR2(r6_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustnessBmarginal, 
          add.lines = custom_R2_rB, keep.stat=("n"),
          column.labels = c("All Banks", "All Banks", "Banks with Respondents"),
          column.separate = c(2, 2, 2),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Checks",
          se = robustnessBmarginalse,
          p = robustnessBmarginal_pval,
          out="RobustnessB.tex", header=FALSE, no.space=TRUE)



# Robustness regressions for second resubmission --------------------------

# Table replicating the first results table, but with only banks with few connections

r14_1 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r14_2 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r14_3 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r14_4 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r14_5 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r14_6 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r14_7 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r14_8 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents < 3 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))


robustness14 <- list(r14_1, r14_2, r14_3, r14_4, r14_5, r14_6, r14_7, r14_8)

robustness14marginal <- marginsfunction(robustness14)
robustness14marginalse <- marginsfunctionSErobust(robustness14)
robustness14marginal_pval <- marginsfunction_pval(robustness14)


custom_R2_r14 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r14_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r14_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r14_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r14_4, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r14_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r14_6, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r14_7, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r14_8, "McKelveyZavoi"),digits = 2)))


stargazer(robustness14marginal,
          add.lines = c(custom_R2_r14), keep.stat=("n"),
          column.labels = c("Banks with Fewer than Three Correspondents", "Banks with Fewer than Three Respondents"),
          column.separate = c(4, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Bank Suspensions and the Role of Correspondents and Respondents (Marginal Effects, Banks with Few Connections)",
          se = robustness14marginalse,
          p = robustness14marginal_pval,
          out="Robustness14.tex", header=FALSE, no.space=TRUE)



# Table replicating the first results table, but with only banks with lots of connections

r15_1 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r15_2 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r15_3 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r15_4 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r15_5 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r15_6 <- glm(Suspended ~ RespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r15_7 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r15_8 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, ServesasCorrespondent==TRUE & BankData$Respondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))


robustness15 <- list(r15_1, r15_2, r15_3, r15_4, r15_5, r15_6, r15_7, r15_8)

robustness15marginal <- marginsfunction(robustness15)
robustness15marginalse <- marginsfunctionSErobust(robustness15)
robustness15marginal_pval <- marginsfunction_pval(robustness15)


custom_R2_r15 = list(c("Pseudo R-Squared", 
                       round(PseudoR2(r15_1, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r15_2, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r15_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r15_4, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r15_5, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r15_6, "McKelveyZavoi"),digits = 2),
                       round(PseudoR2(r15_7, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r15_8, "McKelveyZavoi"),digits = 2)))


stargazer(robustness15marginal,
          add.lines = c(custom_R2_r15), keep.stat=("n"),
          column.labels = c("Banks with Three or More Correspondents", "Banks with Three or More Respondents"),
          column.separate = c(4, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Bank Suspensions and the Role of Correspondents and Respondents (Marginal Effects, Banks with Lots of Connections)",
          se = robustness15marginalse,
          p = robustness15marginal_pval,
          out="Robustness15.tex", header=FALSE, no.space=TRUE)



# Table replicating the first results table, but with only banks with few connections

r16_1 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r16_2 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r16_3 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r16_4 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents < 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))


r16_5 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r16_6 <- glm(Suspended ~ CorrespondentSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r16_7 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r16_8 <- glm(Suspended ~ FractionofCorrespondentsSuspendedPrior2 + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = 
               subset(BankData, BankData$Correspondents > 0 & BankData$Correspondents > 2 & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

robustness16 <- list(r16_1, r16_2, r16_3, r16_4, r16_5, r16_6, r16_7, r16_8)

robustness16marginal <- marginsfunction(robustness16)
robustness16marginalse <- marginsfunctionSErobust(robustness16)
robustness16marginal_pval <- marginsfunction_pval(robustness16)


custom_R2_r16 = list(c("Pseudo R-Squared", 
                       round(PseudoR2(r16_1, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r16_2, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r16_3, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r16_4, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r16_5, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r16_6, "McKelveyZavoi"),digits = 2),
                       round(PseudoR2(r16_7, "McKelveyZavoi"),digits = 2), 
                       round(PseudoR2(r16_8, "McKelveyZavoi"),digits = 2)))


stargazer(robustness16marginal,
          add.lines = c(custom_R2_r16), keep.stat=("n"),
          column.labels = c("One Correspondent", "Three or More Correspondents"),
          column.separate = c(4, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Bank Suspensions and the Role of Correspondents and Respondents (Marginal Effects, Banks with varying connections)",
          se = robustness16marginalse,
          p = robustness16marginal_pval,
          out="Robustness16.tex", header=FALSE, no.space=TRUE)


# Extra Robustness Checks -------------------------------------------------


# Robustness check 1: Table 1, but with number of Correspondents included

r1_1 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + Correspondents + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r1_2 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + Correspondents + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r1_3 <- glm(Suspended ~ RespondentSuspendedPrior + PriorCitySuspensions + Correspondents + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r1_4 <- glm(Suspended ~ RespondentSuspendedPrior + PriorCitySuspensions + Correspondents + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r1_5 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + PriorCitySuspensions + Correspondents + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r1_6 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + PriorCitySuspensions + Correspondents + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))


robustness1 <- list(r1_1, r1_2, r1_3, r1_4, r1_5, r1_6)


robustness1marginal <- marginsfunction(robustness1)
robustness1marginalse <- marginsfunctionSE(robustness1)
robustness1marginal_pval <- marginsfunction_pval(robustness1)


custom_R2_r1 = list(c("Pseudo R-Squared", 
                   round(PseudoR2(r1_1, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r1_2, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r1_3, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r1_4, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r1_5, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r1_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustness1marginal, 
          add.lines = custom_R2_r1, keep.stat=("n"),
          column.labels = c("All Banks", "Banks with Respondents"),
          column.separate = c(2, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 1: Table 1 Including Correspondent Counts",
          se = robustness1marginalse,
          p = robustness1marginal_pval,
          out="Robustness1.tex", header=FALSE, no.space=TRUE)



# Robustness check 2: Table 1, but with number of Correspondents included with interaction

r2_1 <- glm(Suspended ~ CorrespondentSuspendedPrior + Correspondents + CorrespondentSuspendedPriorxCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r2_2 <- glm(Suspended ~ CorrespondentSuspendedPrior + Correspondents + CorrespondentSuspendedPriorxCorrespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r2_3 <- glm(Suspended ~ RespondentSuspendedPrior + Correspondents + RespondentSuspendedPriorxCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r2_4 <- glm(Suspended ~ RespondentSuspendedPrior + Correspondents + RespondentSuspendedPriorxCorrespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r2_5 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + Correspondents + FractionofRespondentsSuspendedPriorxCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r2_6 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + Correspondents + FractionofRespondentsSuspendedPriorxCorrespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

robustness2 <- list(r2_1, r2_2, r2_3, r2_4, r2_5, r2_6)


robustness2marginal <- marginsfunction(robustness2)
robustness2marginalse <- marginsfunctionSE(robustness2)
robustness2marginal_pval <- marginsfunction_pval(robustness2)

custom_R2_r2 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r2_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r2_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r2_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r2_4, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r2_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r2_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustness2marginal, 
          add.lines = custom_R2_r2, keep.stat=("n"),
          column.labels = c("All Banks", "Banks with Respondents"),
          column.separate = c(2, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 2: Table 1 with Correspondent Interaction",
          se = robustness2marginalse,
          p = robustness2marginal_pval,
          out="Robustness2.tex", header=FALSE, no.space=TRUE)


# Robustness check 3: Table 1, columns 1-2, but with additional in-state correspondent suspensions included

r3_1 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r3_2 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r3_3 <- glm(Suspended ~ InStateCorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r3_4 <- glm(Suspended ~ InStateCorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r3_5 <- glm(Suspended ~ CorrespondentSuspendedPrior + InStateCorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r3_6 <- glm(Suspended ~ CorrespondentSuspendedPrior + InStateCorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))


robustness3 <- list(r3_1, r3_2, r3_3, r3_4, r3_5, r3_6)


robustness3marginal <- marginsfunction(robustness3)
robustness3marginalse <- marginsfunctionSE(robustness3)
robustness3marginal_pval <- marginsfunction_pval(robustness3)


custom_R2_r3 = list(c("Pseudo R-Squared", 
                   round(PseudoR2(r3_1, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r3_2, "McKelveyZavoi"),digits = 2),
                   round(PseudoR2(r3_3, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r3_4, "McKelveyZavoi"),digits = 2),
                   round(PseudoR2(r3_5, "McKelveyZavoi"),digits = 2), 
                   round(PseudoR2(r3_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustness3marginal, 
          add.lines = custom_R2_r3, keep.stat=("n"),
          column.labels = c("All Banks"),
          column.separate = c(6),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 3: Impact of In-State Correspondent Failures",
          se = robustness3marginalse,
          p = robustness3marginal_pval,
          out="Robustness3.tex", header=FALSE, no.space=TRUE)


# Robustness Check 4: Compare correspondent failures for banks with two-sided risk (respondents also),
# versus only one-sided risk (don't have respondents)

r4_1 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r4_2 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r4_3 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r4_4 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r4_5 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + CorrespondentSuspendedPriorxServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r4_6 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + CorrespondentSuspendedPriorxServesasCorrespondent + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))


robustness4 <- list(r4_1, r4_2, r4_3, r4_4, r4_5, r4_6)


robustness4marginal <- marginsfunction(robustness4)
robustness4marginalse <- marginsfunctionSE(robustness4)
robustness4marginal_pval <- marginsfunction_pval(robustness4)


custom_R2_r4 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r4_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r4_2, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r4_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r4_4, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r4_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r4_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustness4marginal,
          add.lines = custom_R2_r4, keep.stat=("n"),
          column.labels = c("All Banks"),
          column.separate = c(6),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 4: One-Sided Risk vs Two-Sided Risk, Full Sample",
          se = robustness4marginalse,
          p = robustness4marginal_pval,
          out="Robustness4.tex", header=FALSE, no.space=TRUE)

# Robustness Check 5: Compare correspondent failures for banks with two-sided risk (respondents also),
# versus only one-sided risk (don't have respondents), clearinghouse cities only

r5_1 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_2 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_3 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_4 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_5 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + CorrespondentSuspendedPriorxServesasCorrespondent + PriorCitySuspensions + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_6 <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + CorrespondentSuspendedPriorxServesasCorrespondent + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))


robustness5 <- list(r5_1, r5_2, r5_3, r5_4, r5_5, r5_6)


robustness5marginal <- marginsfunction(robustness5)
robustness5marginalse <- marginsfunctionSE(robustness5)
robustness5marginal_pval <- marginsfunction_pval(robustness5)


custom_R2_r5 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r5_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r5_2, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r5_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r5_4, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r5_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r5_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustness5marginal, 
          add.lines = custom_R2_r5, keep.stat=("n"),
          column.labels = c("Banks in Clearinghouse Cities"),
          column.separate = c(6),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 5: One-Sided Risk vs Two-Sided Risk, Clearinghouse Cities Only",
          se = robustness5marginalse,
          p = robustness5marginal_pval,
          out="Robustness5.tex", header=FALSE, no.space=TRUE)

# Robustness Check 5b: Compare correspondent failures for banks with two-sided risk (respondents also),
# versus only one-sided risk (don't have respondents), clearinghouse cities only, national banks only (C&C Replication)

r5_1b <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + 
              Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_2b <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_3b <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + PriorCitySuspensions + 
              Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_4b <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + PriorCitySuspensions + logFullCapital + 
              Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_5b <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + CorrespondentSuspendedPriorxServesasCorrespondent + PriorCitySuspensions + 
              Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r5_6b <- glm(Suspended ~ CorrespondentSuspendedPrior + ServesasCorrespondent + CorrespondentSuspendedPriorxServesasCorrespondent + PriorCitySuspensions + logFullCapital + 
              Clearinghouse + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, Type1 == "National" & ClearinghouseCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))


robustness5b <- list(r5_1b, r5_2b, r5_3b, r5_4b, r5_5b, r5_6b)


robustness5bmarginal <- marginsfunction(robustness5b)
robustness5bmarginalse <- marginsfunctionSE(robustness5b)
robustness5bmarginal_pval <- marginsfunction_pval(robustness5b)


custom_R2_r5b = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r5_1b, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r5_2b, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r5_3b, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r5_4b, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r5_5b, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r5_6b, "McKelveyZavoi"),digits = 2)))


stargazer(robustness5bmarginal, 
          add.lines = custom_R2_r5b, keep.stat=("n"),
          column.labels = c("National Banks in Clearinghouse Cities"),
          column.separate = c(6),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 5b: One-Sided Risk vs Two-Sided Risk, Clearinghouse Cities Only, National Banks Only",
          se = robustness5bmarginalse,
          p = robustness5bmarginal_pval,
          out="Robustness5b.tex", header=FALSE, no.space=TRUE)





# Robustness Check 6: Replicate Table 1 columns that include capital and add a measure of Equity Quality


r6_1 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital +
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r6_2 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r6_3 <- glm(Suspended ~ RespondentSuspendedPrior + PriorCitySuspensions + logFullCapital +
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r6_4 <- glm(Suspended ~ RespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r6_5 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + PriorCitySuspensions + logFullCapital +
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r6_6 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + PriorCitySuspensions + logFullCapital + EquityQuality + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

robustness6 <- list(r6_1, r6_2, r6_3, r6_4, r6_5, r6_6)


robustness6marginal <- marginsfunction(robustness6)
robustness6marginalse <- marginsfunctionSE(robustness6)
robustness6marginal_pval <- marginsfunction_pval(robustness6)

custom_R2_r6 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r6_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r6_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r6_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r6_4, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r6_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r6_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustness6marginal, 
          add.lines = custom_R2_r6, keep.stat=("n"),
          column.labels = c("All Banks", "Banks with Respondents"),
          column.separate = c(2, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 6: Impact of Equity Quality on Table 1 Results",
          se = robustness6marginalse,
          p = robustness6marginal_pval,
          out="Robustness6.tex", header=FALSE, no.space=TRUE)

# Robustness Check 7: Replicate Table 1 with an interaction term between CorrespondentSuspendedPrior and PriorCitySuspensions


r7_1 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + CorrespondentSuspendedPriorxPriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r7_2 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + CorrespondentSuspendedPriorxPriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r7_3 <- glm(Suspended ~ RespondentSuspendedPrior + PriorCitySuspensions + RespondentSuspendedPriorxPriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r7_4 <- glm(Suspended ~ RespondentSuspendedPrior + PriorCitySuspensions + RespondentSuspendedPriorxPriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r7_5 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + PriorCitySuspensions + FractionofRespondentsSuspendedPriorxPriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r7_6 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + PriorCitySuspensions + FractionofRespondentsSuspendedPriorxPriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))


robustness7 <- list(r7_1, r7_2, r7_3, r7_4, r7_5, r7_6)


robustness7marginal <- marginsfunction(robustness7)
robustness7marginalse <- marginsfunctionSE(robustness7)
robustness7marginal_pval <- marginsfunction_pval(robustness7)

custom_R2_r7 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r7_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r7_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r7_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r7_4, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r7_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r7_6, "McKelveyZavoi"),digits = 2)))


stargazer(robustness7marginal, 
          add.lines = custom_R2_r7, keep.stat=("n"),
          column.labels = c("All Banks", "Banks with Respondents"),
          column.separate = c(2, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 7: Interaction terms with Prior City Suspensions",
          se = robustness7marginalse,
          p = robustness7marginal_pval,
          out="Robustness7.tex", header=FALSE, no.space=TRUE)


# Robustness Check 8: Look at interaction between "Respondent Suspended" and "Number of Respondents"


r8_1 <- glm(Suspended ~ RespondentSuspendedPrior + Respondents + RespondentSuspendedPriorxRespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r8_2 <- glm(Suspended ~ RespondentSuspendedPrior + Respondents + RespondentSuspendedPriorxRespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r8_3 <- glm(Suspended ~ RespondentSuspendedPrior + logRespondents + RespondentSuspendedPriorxlogRespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r8_4 <- glm(Suspended ~ RespondentSuspendedPrior + logRespondents + RespondentSuspendedPriorxlogRespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))


robustness8 <- list(r8_1, r8_2, r8_3, r8_4)


robustness8marginal <- marginsfunction(robustness8)
robustness8marginalse <- marginsfunctionSE(robustness8)
robustness8marginal_pval <- marginsfunction_pval(robustness8)

custom_R2_r8 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r8_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r8_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r8_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r8_3, "McKelveyZavoi"),digits = 2)))


stargazer(robustness8marginal, 
          add.lines = custom_R2_r8, keep.stat=("n"),
          column.labels = c("Banks with Respondents"),
          column.separate = c(4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 8: Interaction between Respondent Suspensions and the Number of Respondents",
          se = robustness8marginalse,
          p = robustness8marginal_pval,
          out="Robustness8.tex", header=FALSE, no.space=TRUE)


# Robustness Check 9: Look at impact of having non-NYC correspondents on Table 2 results


r9_1 <- glm(PreNYSuspensions ~ CorrespondentSuspendedPrior + NonNYCCorrespondents + CorrespondentSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r9_2 <- glm(PreNYSuspensions ~ CorrespondentSuspendedPrior + NonNYCCorrespondents + CorrespondentSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r9_3 <- glm(PostNYSuspensions ~ CorrespondentSuspendedPrior + NonNYCCorrespondents + CorrespondentSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE))

r9_4 <- glm(PostNYSuspensions ~ CorrespondentSuspendedPrior + NonNYCCorrespondents + CorrespondentSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE))


robustness9 <- list(r9_1, r9_2, r9_3, r9_4)


robustness9marginal <- marginsfunction(robustness9)
robustness9marginalse <- marginsfunctionSE(robustness9)
robustness9marginal_pval <- marginsfunction_pval(robustness9)

custom_R2_r9 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r9_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r9_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r9_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r9_3, "McKelveyZavoi"),digits = 2)))


stargazer(robustness9marginal, 
          add.lines = custom_R2_r9, keep.stat=("n"),
          column.labels = c("All Banks"),
          column.separate = c(4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 9: Impact of Non-NYC Correspondents on Table 2 Results",
          se = robustness9marginalse,
          p = robustness9marginal_pval,
          out="Robustness9.tex", header=FALSE, no.space=TRUE)



# Robustness Check 10: Look at impact of having non-NYC correspondents on Table 3 results


r10_1 <- glm(PreNYSuspensions ~ RespondentSuspendedPrior + NonNYCCorrespondents + RespondentSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r10_2 <- glm(PreNYSuspensions ~ FractionofRespondentsSuspendedPrior + NonNYCCorrespondents + FractionofRespondentsSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r10_3 <- glm(PostNYSuspensions ~ RespondentSuspendedPrior + NonNYCCorrespondents + RespondentSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE & ServesasCorrespondent==TRUE))

r10_4 <- glm(PostNYSuspensions ~ FractionofRespondentsSuspendedPrior + NonNYCCorrespondents + FractionofRespondentsSuspendedPriorxNonNYCCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE & ServesasCorrespondent==TRUE))


robustness10 <- list(r10_1, r10_2, r10_3, r10_4)


robustness10marginal <- marginsfunction(robustness10)
robustness10marginalse <- marginsfunctionSE(robustness10)
robustness10marginal_pval <- marginsfunction_pval(robustness10)

custom_R2_r10 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r10_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r10_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r10_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r10_3, "McKelveyZavoi"),digits = 2)))


stargazer(robustness10marginal, 
          add.lines = custom_R2_r10, keep.stat=("n"),
          column.labels = c("Banks with Respondents"),
          column.separate = c(4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 10: Impact of Non-NYC Correspondents on Table 3 Results",
          se = robustness10marginalse,
          p = robustness10marginal_pval,
          out="Robustness10.tex", header=FALSE, no.space=TRUE)



# Robustness Check 11: Look at impact of having other central reserve correspondents on Table 2 results


r11_1 <- glm(PreNYSuspensions ~ CorrespondentSuspendedPrior + OtherCentralReserveCorrespondents + CorrespondentSuspendedPriorxOtherCentralReserveCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r11_2 <- glm(PreNYSuspensions ~ CorrespondentSuspendedPrior + OtherCentralReserveCorrespondents + CorrespondentSuspendedPriorxOtherCentralReserveCorrespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed)))

r11_3 <- glm(PostNYSuspensions ~ CorrespondentSuspendedPrior + OtherCentralReserveCorrespondents + CorrespondentSuspendedPriorxOtherCentralReserveCorrespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE))

r11_4 <- glm(PostNYSuspensions ~ CorrespondentSuspendedPrior + OtherCentralReserveCorrespondents + CorrespondentSuspendedPriorxOtherCentralReserveCorrespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, PreNYSuspensions==FALSE))


robustness11 <- list(r11_1, r11_2, r11_3, r11_4)


robustness11marginal <- marginsfunction(robustness11)
robustness11marginalse <- marginsfunctionSE(robustness11)
robustness11marginal_pval <- marginsfunction_pval(robustness11)

custom_R2_r11 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r11_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r11_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r11_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r11_3, "McKelveyZavoi"),digits = 2)))


stargazer(robustness11marginal, 
          add.lines = custom_R2_r11, keep.stat=("n"),
          column.labels = c("All Banks"),
          column.separate = c(4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 11: Impact of Other Central Reserve Correspondents on Table 2 Results",
          se = robustness11marginalse,
          p = robustness11marginal_pval,
          out="Robustness11.tex", header=FALSE, no.space=TRUE)


# Robustness check 12: Respondent Suspensions and State-Level Deposit Declines Among Respondents

r12_1 <- glm(Suspended ~ RespondentSuspendedPrior2 + StateDepositDeclinesAmongRespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r12_2 <- glm(Suspended ~ RespondentSuspendedPrior2 + StateDepositDeclinesAmongRespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r12_3 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + StateDepositDeclinesAmongRespondents + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))

r12_4 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior2 + StateDepositDeclinesAmongRespondents + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = 
              subset(BankData, ServesasCorrespondent==TRUE & (BankData$DateClosed > "1893-04-21" | is.na(BankData$DateClosed))))



robustness12 <- list(r12_1, r12_2, r12_3, r12_4)


robustness12marginal <- marginsfunction(robustness12)
robustness12marginalse <- marginsfunctionSErobust(robustness12)
robustness12marginal_pval <- marginsfunction_pval(robustness12)


custom_R2_r12 = list(c("Pseudo R-Squared", 
                      round(PseudoR2(r12_1, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r12_2, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r12_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r12_4, "McKelveyZavoi"),digits = 2)))


stargazer(robustness12marginal,
          add.lines = custom_R2_r12, keep.stat=("n"),
          column.labels = c("Banks with Respondents"),
          column.separate = c(4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Respondent Suspensions and State-Level Deposit Declines Among Respondents",
          se = robustness12marginalse,
          p = robustness12marginal_pval,
          out="Robustness12.tex", header=FALSE, no.space=TRUE)



# Robustness check 13: Compare correspondent failures for NYC banks with respondents (one-sided correspondent banks), 
# reserve city banks with two-sided risk (respondents also),
# and only one-sided risk (don't have respondents)

r13_1 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior +  PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & NonNYCReserveCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r13_2 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & NonNYCReserveCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r13_3 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + CorrespondentSuspendedPrior +  PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & NonNYCReserveCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r13_4 <- glm(Suspended ~ FractionofRespondentsSuspendedPrior + CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==TRUE & NonNYCReserveCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r13_5 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==FALSE & NonNYCReserveCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r13_6 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
               Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
             family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==FALSE & NonNYCReserveCity==TRUE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r13_7 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==FALSE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))

r13_8 <- glm(Suspended ~ CorrespondentSuspendedPrior + PriorCitySuspensions + logFullCapital + 
              Type1 + Clearinghouse + ClearinghouseCity + logtotpop + FarmtoTotalOutput, 
            family = binomial(link = "probit"), data = subset(BankData, ServesasCorrespondent==FALSE & (BankData$DateClosed > "1893-04-30" | is.na(BankData$DateClosed))))


robustness13 <- list(r13_1, r13_2, r13_3, r13_4, r13_5, r13_6, r13_7, r13_8)


robustness13marginal <- marginsfunction(robustness13)
robustness13marginalse <- marginsfunctionSE(robustness13)
robustness13marginal_pval <- marginsfunction_pval(robustness13)


custom_R2_r13 = list(c("Pseudo R-Squared",
                      round(PseudoR2(r13_1, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r13_2, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r13_3, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r13_4, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r13_5, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r13_6, "McKelveyZavoi"),digits = 2),
                      round(PseudoR2(r13_7, "McKelveyZavoi"),digits = 2), 
                      round(PseudoR2(r13_8, "McKelveyZavoi"),digits = 2)))


stargazer(robustness13marginal, 
          add.lines = custom_R2_r13, keep.stat=("n"),
          column.labels = c("Reserve City Banks with Respondents", "Reserve City Banks without Respondents"),
          column.separate = c(4, 4),
          dep.var.labels.include = FALSE,
          dep.var.caption = "",
          omit = "Constant",
          title = "Robustness Check 13: One-Sided Risk vs Two-Sided Risk, Three Levels",
          se = robustness13marginalse,
          p = robustness13marginal_pval,
          out="Robustness13.tex", header=FALSE, no.space=TRUE)

